@@ -15,10 +15,10 @@ if [ "$INSTALL_TYPE" == "conda" ]; then
     conda create -n venv --yes python=$PYTHON_VERSION pip
     conda install -yq --name venv $DEPENDS $EXTRA_DEPENDS pytest
 else
-    PIPI="pip install --timeout=60 --find-links=$EXTRA_WHEELS"
+    PIPI="pip install --timeout=60 "
 
-    if [ -n "$USE_PRE" ]; then
-        PIPI="$PIPI --find-links=$PRE_WHEELS --pre";
+    if [ "$USE_PRE" == "1" ]; then
+        PIPI="$PIPI --extra-index-url=$PRE_WHEELS --pre";
     fi
 
     pip install --upgrade virtualenv
