@@ -14,7 +14,8 @@ Subpackages
  core.geometry -- Spherical geometry, coordinate and vector manipulation
  core.meshes   -- Point distributions on the sphere
  data          -- Small testing datasets
- external      -- Interfaces to external tools such as FSL
+ denoise       -- Denoising algorithms
+ direction     -- Manage peaks and tracking
  io            -- Loading/saving of dpy datasets
  reconst       -- Signal reconstruction modules (tensor, spherical harmonics,
                   diffusion spectrum, etc.)
@@ -32,8 +33,6 @@ Utilities
 
 """
 import sys
-if sys.version[0:3] < '2.6':
-    raise ImportError('Dipy needs Python version 2.6 or above')
 
 from .info import __version__
 from .testing import setup_test
