@@ -1,8 +1,10 @@
+import logging
 from dipy.align import floating
 import numpy as np
 import numpy.linalg as npl
 import scipy.ndimage.filters as filters
 
+logger = logging.getLogger(__name__)
 
 class ScaleSpace(object):
     def __init__(self, image, num_levels,
@@ -10,7 +12,7 @@ class ScaleSpace(object):
                  input_spacing=None,
                  sigma_factor=0.2,
                  mask0=False):
-        r""" ScaleSpace
+        """ ScaleSpace
 
         Computes the Scale Space representation of an image. The scale space is
         simply a list of images produced by smoothing the input image with a
@@ -73,7 +75,6 @@ class ScaleSpace(object):
         min_spacing = np.min(input_spacing)
         for i in range(1, num_levels):
             scaling_factor = 2 ** i
-            scaling = np.ndarray((self.dim + 1,))
             # Note: the minimum below is present in ANTS to prevent the scaling
             # from being too large (making the sub-sampled image to be too
             # small) this makes the sub-sampled image at least 32 voxels at
@@ -111,7 +112,7 @@ class ScaleSpace(object):
             self.sigmas.append(sigmas)
 
     def get_expand_factors(self, from_level, to_level):
-        r"""Ratio of voxel size from pyramid level from_level to to_level
+        """Ratio of voxel size from pyramid level from_level to to_level
 
         Given two scale space resolutions a = from_level, b = to_level,
         returns the ratio of voxels size at level b to voxel size at level a
@@ -136,7 +137,7 @@ class ScaleSpace(object):
         return factors
 
     def print_level(self, level):
-        r"""Prints properties of a pyramid level
+        """Prints properties of a pyramid level
 
         Prints the properties of a level of this scale space to standard output
 
@@ -145,14 +146,14 @@ class ScaleSpace(object):
         level : int, 0 <= from_level < L, (L = number of resolutions)
             the scale space level to be printed
         """
-        print('Domain shape: ', self.get_domain_shape(level))
-        print('Spacing: ', self.get_spacing(level))
-        print('Scaling: ', self.get_scaling(level))
-        print('Affine: ', self.get_affine(level))
-        print('Sigmas: ', self.get_sigmas(level))
+        logger.info('Domain shape: ' + str(self.get_domain_shape(level)))
+        logger.info('Spacing: ' + str(self.get_spacing(level)))
+        logger.info('Scaling: ' + str(self.get_scaling(level)))
+        logger.info('Affine: ' + str(self.get_affine(level)))
+        logger.info('Sigmas: ' + str(self.get_sigmas(level)))
 
     def _get_attribute(self, attribute, level):
-        r"""Returns an attribute from the Scale Space at a given level
+        """Returns an attribute from the Scale Space at a given level
 
         Returns the level-th element of attribute if level is a valid level
         of this scale space. Otherwise, returns None.
@@ -175,7 +176,7 @@ class ScaleSpace(object):
         raise ValueError('Invalid pyramid level: '+str(level))
 
     def get_image(self, level):
-        r"""Smoothed image at a given level
+        """Smoothed image at a given level
 
         Returns the smoothed image at the requested level in the Scale Space.
 
@@ -192,7 +193,7 @@ class ScaleSpace(object):
         return self._get_attribute(self.images, level)
 
     def get_domain_shape(self, level):
-        r"""Shape the sub-sampled image must have at a particular level
+        """Shape the sub-sampled image must have at a particular level
 
         Returns the shape the sub-sampled image must have at a particular
         resolution of the scale space (note that this object does not
@@ -212,7 +213,7 @@ class ScaleSpace(object):
         return self._get_attribute(self.domain_shapes, level)
 
     def get_spacing(self, level):
-        r"""Spacings the sub-sampled image must have at a particular level
+        """Spacings the sub-sampled image must have at a particular level
 
         Returns the spacings (voxel sizes) the sub-sampled image must have at a
         particular resolution of the scale space (note that this object does
@@ -232,7 +233,7 @@ class ScaleSpace(object):
         return self._get_attribute(self.spacings, level)
 
     def get_scaling(self, level):
-        r"""Adjustment factor for input-spacing to reflect voxel sizes at level
+        """Adjustment factor for input-spacing to reflect voxel sizes at level
 
         Returns the scaling factor that needs to be applied to the input
         spacing (the voxel sizes of the image at level 0 of the scale space) to
@@ -252,7 +253,7 @@ class ScaleSpace(object):
         return self._get_attribute(self.scalings, level)
 
     def get_affine(self, level):
-        r"""Voxel-to-space transformation at a given level
+        """Voxel-to-space transformation at a given level
 
         Returns the voxel-to-space transformation associated with the
         sub-sampled image at a particular resolution of the scale space (note
@@ -272,7 +273,7 @@ class ScaleSpace(object):
         return self._get_attribute(self.affines, level)
 
     def get_affine_inv(self, level):
-        r"""Space-to-voxel transformation at a given level
+        """Space-to-voxel transformation at a given level
 
         Returns the space-to-voxel transformation associated with the
         sub-sampled image at a particular resolution of the scale space (note
@@ -292,7 +293,7 @@ class ScaleSpace(object):
         return self._get_attribute(self.affine_invs, level)
 
     def get_sigmas(self, level):
-        r"""Smoothing parameters used at a given level
+        """Smoothing parameters used at a given level
 
         Returns the smoothing parameters (a scalar for each axis) used at the
         requested level of the scale space
@@ -315,7 +316,7 @@ class IsotropicScaleSpace(ScaleSpace):
                  image_grid2world=None,
                  input_spacing=None,
                  mask0=False):
-        r""" IsotropicScaleSpace
+        """ IsotropicScaleSpace
 
         Computes the Scale Space representation of an image using isotropic
         smoothing kernels for all scales. The scale space is simply a list
