@@ -1,5 +1,3 @@
-from __future__ import division, print_function, absolute_import
-
 """ Benchmarks for bounding_box
 
 Run all benchmarks with::
@@ -7,13 +5,9 @@ Run all benchmarks with::
     import dipy.reconst as dire
     dire.bench()
 
-If you have doctests enabled by default in nose (with a noserc file or
-environment variable), and you have a numpy version <= 1.6.1, this will also
-run the doctests, let's hope they pass.
+With Pytest, Run this benchmark with:
 
-Run this benchmark with:
-
-    nosetests -s --match '(?:^|[\\b_\\.//-])[Bb]ench' /path/to/bench_bounding_box.py
+    pytest -svv -c bench.ini /path/to/bench_bounding_box.py
 """
 import numpy as np
 from numpy.testing import measure
