@@ -5,16 +5,10 @@ Run all benchmarks with::
     import dipy.reconst as dire
     dire.bench()
 
-If you have doctests enabled by default in nose (with a noserc file or
-environment variable), and you have a numpy version <= 1.6.1, this will also
-run the doctests, let's hope they pass.
+With Pytest, Run this benchmark with:
 
-
-Run this benchmark with:
-
-    nosetests -s --match '(?:^|[\\b_\\.//-])[Bb]ench' /path/to/bench_squash.py
+    pytest -svv -c bench.ini /path/to/bench_squash.py
 """
-from __future__ import division, print_function, absolute_import
 
 from functools import reduce
 
@@ -121,7 +115,6 @@ def old_squash(arr, mask=None, fill=0):
 
 
 def bench_quick_squash():
-    # nosetests -s --match '(?:^|[\\b_\\.//-])[Bb]ench'
     repeat = 10
     shape = (300, 200)
     arrs = np.zeros(shape, dtype=object)
