@@ -15,16 +15,16 @@ from dipy.sims.voxel import single_tensor
 
 from dipy.reconst.multi_voxel import multi_voxel_fit
 from dipy.reconst.dti import TensorModel, fractional_anisotropy
-from dipy.reconst.shm import (sph_harm_ind_list, real_sph_harm,
+from dipy.reconst.shm import (sph_harm_ind_list, real_sh_descoteaux_from_index,
                               sph_harm_lookup, lazy_index, SphHarmFit,
-                              real_sym_sh_basis, sh_to_rh, forward_sdeconv_mat,
+                              real_sh_descoteaux, sh_to_rh, forward_sdeconv_mat,
                               SphHarmModel)
 from dipy.reconst.utils import _roi_in_volume, _mask_from_roi
 
 from dipy.direction.peaks import peaks_from_model
 from dipy.core.geometry import vec2vec_rotmat
 
-from dipy.utils.deprecator import deprecate_with_version
+from dipy.utils.deprecator import deprecate_with_version, deprecated_params
 
 
 @deprecate_with_version("dipy.reconst.csdeconv.auto_response is deprecated, "
@@ -158,7 +158,7 @@ class AxSymShResponse(object):
         """A basis that maps the response coefficients onto a sphere."""
         theta = sphere.theta[:, None]
         phi = sphere.phi[:, None]
-        return real_sph_harm(self.m, self.n, theta, phi)
+        return real_sh_descoteaux_from_index(self.m, self.n, theta, phi)
 
     def on_sphere(self, sphere):
         """Evaluates the response function on sphere."""
@@ -242,7 +242,8 @@ class ConstrainedSphericalDeconvModel(SphHarmModel):
         x, y, z = gtab.gradients[self._where_dwi].T
         r, theta, phi = cart2sphere(x, y, z)
         # for the gradient sphere
-        self.B_dwi = real_sph_harm(m, n, theta[:, None], phi[:, None])
+        self.B_dwi = real_sh_descoteaux_from_index(
+            m, n, theta[:, None], phi[:, None])
 
         # for the sphere used in the regularization positivity constraint
         self.sphere = reg_sphere or small_sphere
@@ -252,7 +253,8 @@ class ConstrainedSphericalDeconvModel(SphHarmModel):
             self.sphere.y,
             self.sphere.z
         )
-        self.B_reg = real_sph_harm(m, n, theta[:, None], phi[:, None])
+        self.B_reg = real_sh_descoteaux_from_index(
+            m, n, theta[:, None], phi[:, None])
 
         self.response = response
         if isinstance(response, AxSymShResponse):
@@ -317,7 +319,7 @@ class ConstrainedSphericalDeconvModel(SphHarmModel):
         else:
             x, y, z = gtab.gradients[~gtab.b0s_mask].T
             r, theta, phi = cart2sphere(x, y, z)
-            SH_basis, m, n = real_sym_sh_basis(self.sh_order, theta, phi)
+            SH_basis, m, n = real_sh_descoteaux(self.sh_order, theta, phi)
 
         # Because R is diagonal, the matrix multiply is written as a multiply
         predict_matrix = SH_basis * self.R.diagonal()
@@ -393,7 +395,8 @@ class ConstrainedSDTModel(SphHarmModel):
         x, y, z = gtab.gradients[self._where_dwi].T
         r, theta, phi = cart2sphere(x, y, z)
         # for the gradient sphere
-        self.B_dwi = real_sph_harm(m, n, theta[:, None], phi[:, None])
+        self.B_dwi = real_sh_descoteaux_from_index(
+            m, n, theta[:, None], phi[:, None])
 
         # for the odf sphere
         if reg_sphere is None:
@@ -406,7 +409,8 @@ class ConstrainedSDTModel(SphHarmModel):
             self.sphere.y,
             self.sphere.z
         )
-        self.B_reg = real_sph_harm(m, n, theta[:, None], phi[:, None])
+        self.B_reg = real_sh_descoteaux_from_index(
+            m, n, theta[:, None], phi[:, None])
 
         self.R, self.P = forward_sdt_deconv_mat(ratio, n)
 
@@ -1069,9 +1073,10 @@ def _get_response(S0s, lambdas):
     return response, ratio
 
 
+@deprecated_params('nbr_processes', 'num_processes', since='1.4', until='1.5')
 def recursive_response(gtab, data, mask=None, sh_order=8, peak_thr=0.01,
                        init_fa=0.08, init_trace=0.0021, iter=8,
-                       convergence=0.001, parallel=True, nbr_processes=None,
+                       convergence=0.001, parallel=True, num_processes=None,
                        sphere=default_sphere):
     """ Recursive calibration of response function using peak threshold
 
@@ -1101,9 +1106,11 @@ def recursive_response(gtab, data, mask=None, sh_order=8, peak_thr=0.01,
     parallel : bool, optional
         Whether to use parallelization in peak-finding during the calibration
         procedure. Default: True
-    nbr_processes: int
+    num_processes : int, optional
         If `parallel` is True, the number of subprocesses to use
-        (default multiprocessing.cpu_count()).
+        (default multiprocessing.cpu_count()). If < 0 the maximal number of
+        cores minus |num_processes + 1| is used (enter -1 to use as many cores
+        as possible). 0 raises an error.
     sphere : Sphere, optional.
         The sphere used for peak finding. Default: default_sphere.
 
@@ -1151,7 +1158,7 @@ def recursive_response(gtab, data, mask=None, sh_order=8, peak_thr=0.01,
                                      relative_peak_threshold=peak_thr,
                                      min_separation_angle=25,
                                      parallel=parallel,
-                                     nbr_processes=nbr_processes)
+                                     num_processes=num_processes)
 
         dirs = csd_peaks.peak_dirs
         vals = csd_peaks.peak_values
@@ -1167,7 +1174,8 @@ def recursive_response(gtab, data, mask=None, sh_order=8, peak_thr=0.01,
             x, y, z = rot_gradients[where_dwi].T
             r, theta, phi = cart2sphere(x, y, z)
             # for the gradient sphere
-            B_dwi = real_sph_harm(0, n, theta[:, None], phi[:, None])
+            B_dwi = real_sh_descoteaux_from_index(
+                0, n, theta[:, None], phi[:, None])
             r_sh_all += np.linalg.lstsq(B_dwi, data[num_vox, where_dwi],
                                         rcond=-1)[0]
 
