@@ -16,7 +16,7 @@ from dipy.reconst.utils import _roi_in_volume, _mask_from_roi
 from dipy.sims.voxel import single_tensor
 
 from dipy.utils.optpkg import optional_package
-cvx, have_cvxpy, _ = optional_package("cvxpy")
+cvxpy, have_cvxpy, _ = optional_package("cvxpy")
 
 SH_CONST = .5 / np.sqrt(np.pi)
 
@@ -47,7 +47,7 @@ def multi_tissue_basis(gtab, sh_order, iso_comp):
         raise ValueError(msg)
     r, theta, phi = geo.cart2sphere(*gtab.gradients.T)
     m, n = shm.sph_harm_ind_list(sh_order)
-    B = shm.real_sph_harm(m, n, theta[:, None], phi[:, None])
+    B = shm.real_sh_descoteaux_from_index(m, n, theta[:, None], phi[:, None])
     B[np.ix_(gtab.b0s_mask, n > 0)] = 0.
 
     iso = np.empty([B.shape[0], iso_comp])
@@ -227,7 +227,7 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         multiplier_matrix = _inflate_response(response, gtab, n, delta)
 
         r, theta, phi = geo.cart2sphere(*reg_sphere.vertices.T)
-        odf_reg, _, _ = shm.real_sym_sh_basis(sh_order, theta, phi)
+        odf_reg, _, _ = shm.real_sh_descoteaux(sh_order, theta, phi)
         reg = np.zeros([i + iso for i in odf_reg.shape])
         reg[:iso, :iso] = np.eye(iso)
         reg[iso:, iso:] = odf_reg
@@ -288,8 +288,33 @@ class MultiShellDeconvModel(shm.SphHarmModel):
         return pred_sig
 
     @multi_voxel_fit
-    def fit(self, data):
+    def fit(self, data, verbose=True):
+        """Fits the model to diffusion data and returns the model fit.
+
+        Sometimes the solving process of some voxels can end in a SolverError
+        from cvxpy. This might be attributed to the response functions not
+        being tuned properly, as the solving process is very sensitive to it.
+        The method will fill the problematic voxels with a NaN value, so that
+        it is traceable. The user should check for the number of NaN values and
+        could then fill the problematic voxels with zeros, for example.
+        Running a fit again only on those problematic voxels can also work.
+
+        Parameters
+        ----------
+        data : ndarray
+            The diffusion data to fit the model on.
+        verbose : bool (optional)
+            Whether to show warnings when a SolverError appears or not.
+            Default: True
+        """
         coeff = self.fitter(data)
+        if verbose:
+            if np.isnan(coeff[..., 0]):
+                msg = """Voxel could not be solved properly and ended up with a
+                SolverError. Proceeding to fill it with NaN values.
+                """
+                warnings.warn(msg, UserWarning)
+
         return MSDeconvFit(self, coeff, None)
 
 
@@ -353,15 +378,24 @@ def solve_qp(P, Q, G, H):
     x : array
         Optimal solution to the QP problem.
     """
-    x = cvx.Variable(Q.shape[0])
-    P = cvx.Constant(P)
-    objective = cvx.Minimize(0.5 * cvx.quad_form(x, P) + Q * x)
-    constraints = [G*x <= H]
+    x = cvxpy.Variable(Q.shape[0])
+    P = cvxpy.Constant(P)
+    if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+        objective = cvxpy.Minimize(0.5 * cvxpy.quad_form(x, P) + Q * x)
+        constraints = [G * x <= H]
+    else:
+        objective = cvxpy.Minimize(0.5 * cvxpy.quad_form(x, P) + Q @ x)
+        constraints = [G @ x <= H]
 
     # setting up the problem
-    prob = cvx.Problem(objective, constraints)
-    prob.solve()
-    opt = np.array(x.value).reshape((Q.shape[0],))
+    prob = cvxpy.Problem(objective, constraints)
+    try:
+        prob.solve()
+        opt = np.array(x.value).reshape((Q.shape[0],))
+    except cvxpy.error.SolverError:
+        opt = np.empty((Q.shape[0],))
+        opt[:] = np.NaN
+
     return opt
 
 
@@ -421,8 +455,8 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     MultiShellResponse
         MultiShellResponse object.
     """
-    NUMPY_1_12_PLUS = LooseVersion(np.__version__) > LooseVersion('1.12.0')
-    rcond_value = None if NUMPY_1_12_PLUS else -1
+    NUMPY_1_14_PLUS = LooseVersion(np.__version__) >= LooseVersion('1.14.0')
+    rcond_value = None if NUMPY_1_14_PLUS else -1
 
     bvals = np.array(bvals, copy=True)
     evecs = np.zeros((3, 3))
@@ -439,8 +473,8 @@ def multi_shell_fiber_response(sh_order, bvals, wm_rf, gm_rf, csf_rf,
     big_sphere = sphere.subdivide()
     theta, phi = big_sphere.theta, big_sphere.phi
 
-    B = shm.real_sph_harm(m, n, theta[:, None], phi[:, None])
-    A = shm.real_sph_harm(0, 0, 0, 0)
+    B = shm.real_sh_descoteaux_from_index(m, n, theta[:, None], phi[:, None])
+    A = shm.real_sh_descoteaux_from_index(0, 0, 0, 0)
 
     response = np.empty([len(bvals), len(n) + 2])
 
@@ -516,10 +550,10 @@ def mask_for_response_msmt(gtab, data, roi_center=None, roi_radii=10,
         for WM.
     mask_gm : ndarray
         Mask of voxels within the ROI and with FA below the FA threshold
-        for GM and with MD above the MD threshold for GM.
+        for GM and with MD below the MD threshold for GM.
     mask_csf : ndarray
         Mask of voxels within the ROI and with FA below the FA threshold
-        for CSF and with MD above the MD threshold for CSF.
+        for CSF and with MD below the MD threshold for CSF.
 
     Notes
     -----
@@ -626,12 +660,12 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
 
     Returns
     -------
-    response_wm : ndarray, (len(gtab.bvals)-1, 4)
-        (`evals`, `S0`) for WM for each bvalues (except b0).
-    response_gm : ndarray, (len(gtab.bvals)-1, 4)
-        (`evals`, `S0`) for GM for each bvalues (except b0).
-    response_csf : ndarray, (len(gtab.bvals)-1, 4)
-        (`evals`, `S0`) for CSF for each bvalues (except b0).
+    response_wm : ndarray, (len(unique_bvals_tolerance(gtab.bvals))-1, 4)
+        (`evals`, `S0`) for WM for each unique bvalues (except b0).
+    response_gm : ndarray, (len(unique_bvals_tolerance(gtab.bvals))-1, 4)
+        (`evals`, `S0`) for GM for each unique bvalues (except b0).
+    response_csf : ndarray, (len(unique_bvals_tolerance(gtab.bvals))-1, 4)
+        (`evals`, `S0`) for CSF for each unique bvalues (except b0).
 
     Notes
     -----
@@ -652,6 +686,7 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
 
     bvals = gtab.bvals
     bvecs = gtab.bvecs
+    btens = gtab.btens
 
     list_bvals = unique_bvals_tolerance(bvals, tol)
 
@@ -668,10 +703,15 @@ def response_from_mask_msmt(gtab, data, mask_wm, mask_gm, mask_csf, tol=20):
             bvecs_sub = np.concatenate([[bvecs[b0_indices[0]]],
                                        bvecs[indices]])
             bvals_sub = np.concatenate([[0], bvals[indices]])
+            if btens is not None:
+                btens_b0 = btens[b0_indices[0]].reshape((1, 3, 3))
+                btens_sub = np.concatenate([btens_b0, btens[indices]])
+            else:
+                btens_sub = None
 
             data_conc = np.concatenate([b0_map, data[..., indices]], axis=3)
 
-            gtab = gradient_table(bvals_sub, bvecs_sub)
+            gtab = gradient_table(bvals_sub, bvecs_sub, btens=btens_sub)
             response, _ = response_from_mask_ssst(gtab, data_conc, mask)
 
             responses.append(list(np.concatenate([response[0], [response[1]]])))
@@ -713,12 +753,12 @@ def auto_response_msmt(gtab, data, tol=20, roi_center=None, roi_radii=10,
 
     Returns
     -------
-    response_wm : ndarray, (len(gtab.bvals)-1, 4)
-        (`evals`, `S0`) for WM for each bvalues (except b0).
-    response_gm : ndarray, (len(gtab.bvals)-1, 4)
-        (`evals`, `S0`) for GM for each bvalues (except b0).
-    response_csf : ndarray, (len(gtab.bvals)-1, 4)
-        (`evals`, `S0`) for CSF for each bvalues (except b0).
+    response_wm : ndarray, (len(unique_bvals_tolerance(gtab.bvals))-1, 4)
+        (`evals`, `S0`) for WM for each unique bvalues (except b0).
+    response_gm : ndarray, (len(unique_bvals_tolerance(gtab.bvals))-1, 4)
+        (`evals`, `S0`) for GM for each unique bvalues (except b0).
+    response_csf : ndarray, (len(unique_bvals_tolerance(gtab.bvals))-1, 4)
+        (`evals`, `S0`) for CSF for each unique bvalues (except b0).
 
     Notes
     -----
@@ -736,9 +776,9 @@ def auto_response_msmt(gtab, data, tol=20, roi_center=None, roi_radii=10,
     list_bvals = unique_bvals_tolerance(gtab.bvals)
     if not np.all(list_bvals <= 1200):
         msg_bvals = """Some b-values are higher than 1200.
-        The DTI fit might be affected. It is adviced use mask_for_response_msmt
-        with bvalues lower than 1200, followed by response_from_mask_msmt
-        to overcome this."""
+        The DTI fit might be affected. It is advised to use
+        mask_for_response_msmt with bvalues lower than 1200, followed by
+        response_from_mask_msmt with all bvalues to overcome this."""
         warnings.warn(msg_bvals, UserWarning)
     mask_wm, mask_gm, mask_csf = mask_for_response_msmt(gtab, data,
                                                         roi_center,
