@@ -4,13 +4,13 @@ from dipy.core.sphere import Sphere
 from numpy.testing import assert_, assert_equal, run_module_suite
 
 
-class TestModel(Cache):
+class DummyModel(Cache):
     def __init__(self):
         pass
 
 
 def test_basic_cache():
-    t = TestModel()
+    t = DummyModel()
     s = Sphere(theta=[0], phi=[0])
 
     assert_(t.cache_get("design_matrix", s) is None)
