@@ -1,28 +1,27 @@
 """ Testing DKI """
 
-from __future__ import division, print_function, absolute_import
-
 import numpy as np
 import random
 import dipy.reconst.dki as dki
 import dipy.reconst.dti as dti
 from numpy.testing import (assert_array_almost_equal, assert_array_equal,
-                           assert_almost_equal)
-from nose.tools import assert_raises
+                           assert_almost_equal, assert_raises)
 from dipy.sims.voxel import multi_tensor_dki
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.core.gradients import gradient_table
-from dipy.data import get_data
+from dipy.data import get_fnames
 from dipy.reconst.dti import (from_lower_triangular, decompose_tensor)
 from dipy.reconst.dki import (mean_kurtosis, carlson_rf,  carlson_rd,
-                              axial_kurtosis, radial_kurtosis, _positive_evals,
-                              lower_triangular)
+                              axial_kurtosis, radial_kurtosis,
+                              mean_kurtosis_tensor,
+                              _positive_evals, lower_triangular,
+                              kurtosis_fractional_anisotropy)
 
 from dipy.core.sphere import Sphere
-from dipy.data import get_sphere
-from dipy.core.geometry import (sphere2cart, perpendicular_directions)
+from dipy.data import default_sphere
+from dipy.core.geometry import sphere2cart
 
-fimg, fbvals, fbvecs = get_data('small_64D')
+fimg, fbvals, fbvecs = get_fnames('small_64D')
 bvals, bvecs = read_bvals_bvecs(fbvals, fbvecs)
 gtab = gradient_table(bvals, bvecs)
 
@@ -48,10 +47,10 @@ crossing_ref = np.concatenate((evals_cross, evecs_cross[0], evecs_cross[1],
                                evecs_cross[2], kt_cross), axis=0)
 
 # Simulation 2. Spherical kurtosis tensor.- for white matter, this can be a
-# biological implaussible scenario, however this simulation is usefull for
+# biological implausible scenario, however this simulation is useful for
 # testing the estimation of directional apparent kurtosis and the mean
 # kurtosis, since its directional and mean kurtosis ground truth are a constant
-# which can be easly mathematicaly calculated.
+# which can be calculated easily mathematically.
 Di = 0.00099
 De = 0.00226
 mevals_sph = np.array([[Di, Di, Di], [De, De, De]])
@@ -62,7 +61,7 @@ signal_sph, dt_sph, kt_sph = multi_tensor_dki(gtab_2s, mevals_sph, S0=100,
 evals_sph, evecs_sph = decompose_tensor(from_lower_triangular(dt_sph))
 params_sph = np.concatenate((evals_sph, evecs_sph[0], evecs_sph[1],
                              evecs_sph[2], kt_sph), axis=0)
-# Compute ground truth - since KT is spherical, appparent kurtosic coeficient
+# Compute ground truth - since KT is spherical, apparent kurtosis coefficient
 # for all gradient directions and mean kurtosis have to be equal to Kref_sph.
 f = 0.5
 Dg = f*Di + (1-f)*De
@@ -70,7 +69,7 @@ Kref_sphere = 3 * f * (1-f) * ((Di-De) / Dg) ** 2
 
 # Simulation 3. Multi-voxel simulations - dataset of four voxels is simulated.
 # Since the objective of this simulation is to see if procedures are able to
-# work with multi-dimentional data all voxels contains the same crossing signal
+# work with multi-dimensional data all voxels contains the same crossing signal
 # produced in simulation 1.
 
 DWI = np.zeros((2, 2, 1, len(gtab_2s.bvals)))
@@ -118,6 +117,18 @@ def test_dki_fits():
 
     assert_array_almost_equal(dki_wlsF.model_params, crossing_ref)
 
+    # NLS fitting
+    dki_nlsM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="NLS")
+    dki_nlsF = dki_nlsM.fit(signal_cross)
+
+    assert_array_almost_equal(dki_nlsF.model_params, crossing_ref)
+
+    # Restore fitting
+    dki_rtM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="RT", sigma=2)
+    dki_rtF = dki_rtM.fit(signal_cross)
+
+    assert_array_almost_equal(dki_rtF.model_params, crossing_ref)
+
     # testing multi-voxels
     dkiF_multi = dkiM.fit(DWI)
     assert_array_almost_equal(dkiF_multi.model_params, multi_params)
@@ -125,9 +136,12 @@ def test_dki_fits():
     dkiF_multi = dki_wlsM.fit(DWI)
     assert_array_almost_equal(dkiF_multi.model_params, multi_params)
 
+    dkiF_multi = dki_rtM.fit(DWI)
+    assert_array_almost_equal(dkiF_multi.model_params, multi_params)
+
 
 def test_apparent_kurtosis_coef():
-    """ Apparent kurtosis coeficients are tested for a spherical kurtosis
+    """ Apparent kurtosis coefficients are tested for a spherical kurtosis
     tensor """
 
     sph = Sphere(xyz=gtab.bvecs[gtab.bvals > 0])
@@ -183,7 +197,7 @@ def test_carlson_rf():
     y = np.array([[2.0, 1.0], [3.0, 3.0]])
     z = np.array([[0.0, 0.0], [4.0, 4.0]])
 
-    # Defene reference outputs
+    # Define reference outputs
     RF_ref = np.array([[1.3110287771461, 1.8540746773014],
                        [0.58408284167715, 0.58408284167715]])
 
@@ -198,7 +212,7 @@ def test_carlson_rf():
     y = np.array([-1j, 1j, -1j, 1j])
     z = np.array([0.0, 0.0, 2, 1 - 1j])
 
-    # Defene reference outputs
+    # Define reference outputs
     RF_ref = np.array([1.8540746773014, 0.79612586584234 - 1.2138566698365j,
                        1.0441445654064, 0.93912050218619 - 0.53296252018635j])
     # Compute integrals
@@ -313,7 +327,7 @@ def test_Wrotate_crossing_fibers():
 
 def test_Wcons():
 
-    # Construct the 4D kurtosis tensor manualy from the crossing fiber kt
+    # Construct the 4D kurtosis tensor manually from the crossing fiber kt
     # simulate
     Wfit = np.zeros([3, 3, 3, 3])
 
@@ -390,7 +404,7 @@ def test_Wcons():
 
 
 def test_spherical_dki_statistics():
-    # tests if MK, AK and RK are equal to expected values of a spherical
+    # tests if MK, AK, RK and MSK are equal to expected values of a spherical
     # kurtosis tensor
 
     # Define multi voxel spherical kurtosis simulations
@@ -405,17 +419,25 @@ def test_spherical_dki_statistics():
     MRef[1, 1, 1] = MRef[1, 0, 0] = MRef[1, 0, 1] = 0
 
     # Mean kurtosis analytical solution
-    MK_multi = mean_kurtosis(MParam)
+    MK_multi = mean_kurtosis(MParam, analytical=True)
     assert_array_almost_equal(MK_multi, MRef)
 
     # radial kurtosis analytical solution
-    RK_multi = radial_kurtosis(MParam)
+    RK_multi = radial_kurtosis(MParam, analytical=True)
     assert_array_almost_equal(RK_multi, MRef)
 
     # axial kurtosis analytical solution
-    AK_multi = axial_kurtosis(MParam)
+    AK_multi = axial_kurtosis(MParam, analytical=True)
     assert_array_almost_equal(AK_multi, MRef)
 
+    # mean kurtosis tensor analytical solution
+    MSK_multi = mean_kurtosis_tensor(MParam)
+    assert_array_almost_equal(MSK_multi, MRef)
+
+    # kurtosis fractional anisotropy (isotropic case kfa=0)
+    KFA_multi = kurtosis_fractional_anisotropy(MParam)
+    assert_array_almost_equal(KFA_multi, 0*MRef)
+
 
 def test_compare_MK_method():
     # tests if analytical solution of MK is equal to the average of directional
@@ -426,14 +448,12 @@ def test_compare_MK_method():
     dkiF = dkiM.fit(signal_cross)
 
     # MK analytical solution
-    MK_as = dkiF.mk()
+    MK_as = dkiF.mk(None, None, analytical=True)
 
     # MK numerical method
-    sph = Sphere(xyz=gtab.bvecs[gtab.bvals > 0])
-    MK_nm = np.mean(dki.apparent_kurtosis_coef(dkiF.model_params, sph),
-                    axis=-1)
+    MK_nm = dkiF.mk(None, None, analytical=False)
 
-    assert_array_almost_equal(MK_as, MK_nm, decimal=1)
+    assert_array_almost_equal(MK_as, MK_nm, decimal=3)
 
 
 def test_single_voxel_DKI_stats():
@@ -491,15 +511,11 @@ def test_compare_RK_methods():
     dkiM = dki.DiffusionKurtosisModel(gtab_2s)
     dkiF = dkiM.fit(signal_cross)
 
-    # MK analytical solution
-    RK_as = dkiF.rk()
+    # RK analytical solution
+    RK_as = dkiF.rk(analytical=True)
 
-    # MK numerical method
-    evecs = dkiF.evecs
-    p_dir = perpendicular_directions(evecs[:, 0], num=30, half=True)
-    ver = Sphere(xyz=p_dir)
-    RK_nm = np.mean(dki.apparent_kurtosis_coef(dkiF.model_params, ver),
-                    axis=-1)
+    # RK numerical method
+    RK_nm = dkiF.rk(analytical=False)
 
     assert_array_almost_equal(RK_as, RK_nm)
 
@@ -519,20 +535,17 @@ def test_MK_singularities():
                                               angles=angles_90,
                                               fractions=frac_cross, snr=None)
         dkiF = dkiM.fit(s_90)
-        MK = dkiF.mk()
+        MK_an = dkiF.mk(analytical=True)
+        MK_nm = dkiF.mk(analytical=False)
 
-        sph = Sphere(xyz=gtab.bvecs[gtab.bvals > 0])
-
-        MK_nm = np.mean(dkiF.akc(sph))
-
-        assert_almost_equal(MK, MK_nm, decimal=2)
+        assert_almost_equal(MK_an, MK_nm, decimal=3)
 
         # test singularity L1 == L3 and L1 != L2
         # since L1 is defined as the larger eigenvalue and L3 the smallest
-        # eigenvalue, this singularity teoretically will never be called,
+        # eigenvalue, this singularity theoretically will never be called,
         # because for L1 == L3, L2 have also to be  = L1 and L2.
         # Nevertheless, I decided to include this test since this singularity
-        # is revelant for cases that eigenvalues are not ordered
+        # is relevant for cases that eigenvalues are not ordered
 
         # artificially revert the eigenvalue and eigenvector order
         dki_params = dkiF.model_params.copy()
@@ -545,10 +558,10 @@ def test_MK_singularities():
         dki_params[10] = dkiF.model_params[11]
         dki_params[11] = dkiF.model_params[10]
 
-        MK = dki.mean_kurtosis(dki_params)
-        MK_nm = np.mean(dki.apparent_kurtosis_coef(dki_params, sph))
+        MK_an = dki.mean_kurtosis(dki_params, analytical=True)
+        MK_nm = dki.mean_kurtosis(dki_params, analytical=False)
 
-        assert_almost_equal(MK, MK_nm, decimal=2)
+        assert_almost_equal(MK_an, MK_nm, decimal=3)
 
 
 def test_dki_errors():
@@ -585,7 +598,7 @@ def test_dki_errors():
 
 def test_kurtosis_maximum():
     # TEST 1
-    # simulate a crossing fibers interserting at 70 degrees. The first fiber
+    # simulate a crossing fibers intersecting at 70 degrees. The first fiber
     # is aligned to the x-axis while the second fiber is aligned to the x-z
     # plane with an angular deviation of 70 degrees from the first one.
     # According to Neto Henriques et al, 2015 (NeuroImage 111: 85-99), the
@@ -602,7 +615,7 @@ def test_kurtosis_maximum():
     R = dkiF.evecs
     evals = dkiF.evals
     dt = lower_triangular(np.dot(np.dot(R, np.diag(evals)), R.T))
-    sphere = get_sphere('symmetric724')
+    sphere = default_sphere
 
     # compute maxima
     k_max_cross, max_dir = dki._voxel_kurtosis_maximum(dt, MD, kt, sphere,
@@ -716,19 +729,48 @@ def test_multi_voxel_kurtosis_maximum():
     # prepare inputs
     dkiM = dki.DiffusionKurtosisModel(gtab_2s, fit_method="WLS")
     dkiF = dkiM.fit(DWIsim)
-    sphere = get_sphere('symmetric724')
 
     # TEST - when no sphere is given
     k_max = dki.kurtosis_maximum(dkiF.model_params)
-    assert_almost_equal(k_max, RK, decimal=5)
+    assert_almost_equal(k_max, RK, decimal=4)
 
     # TEST - when sphere is given
-    k_max = dki.kurtosis_maximum(dkiF.model_params, sphere)
-    assert_almost_equal(k_max, RK, decimal=5)
+    k_max = dki.kurtosis_maximum(dkiF.model_params, default_sphere)
+    assert_almost_equal(k_max, RK, decimal=4)
 
     # TEST - when mask is given
     mask = np.ones((2, 2, 2), dtype='bool')
     mask[1, 1, 1] = 0
     RK[1, 1, 1] = 0
     k_max = dki.kurtosis_maximum(dkiF.model_params, mask=mask)
-    assert_almost_equal(k_max, RK, decimal=5)
+    assert_almost_equal(k_max, RK, decimal=4)
+
+
+def test_kurtosis_fa():
+    # KFA = sqrt(4/5) if kurtosis is non-zero only in one direction
+    mevals = np.array([[0.002, 0, 0], [0.003, 0, 0]])
+    angles = [(45, 0), (45, 0)]
+    fie = 0.5
+    frac = [fie*100, (1-fie)*100]
+    signal, dt, kt = multi_tensor_dki(gtab_2s, mevals, S0=100, angles=angles,
+                                      fractions=frac, snr=None)
+
+    dkiM = dki.DiffusionKurtosisModel(gtab_2s)
+    dkiF = dkiM.fit(signal)
+    dkiF.kfa
+    assert_almost_equal(dkiF.kfa, np.sqrt(4/5))
+
+    # KFA = sqrt(13/5) for systems of two tensors with same AD and RD values
+    # See appendix of Gleen et al., 2015 Quantitative assessment of diffusional
+    # kurtosis anisotropy. NMR Biomed 28; 448-459. doi:10.1002/nbm.3271
+    mevals = np.array([[0.003, 0.001, 0.001], [0.003, 0.001, 0.001]])
+    angles = [(40, -10), (-45, 10)]
+    fie = 0.5
+    frac = [fie*100, (1-fie)*100]
+    signal, dt, kt = multi_tensor_dki(gtab_2s, mevals, S0=100, angles=angles,
+                                      fractions=frac, snr=None)
+
+    dkiM = dki.DiffusionKurtosisModel(gtab_2s)
+    dkiF = dkiM.fit(signal)
+    dkiF.kfa
+    assert_almost_equal(dkiF.kfa, np.sqrt(13/15))
