@@ -1,16 +1,15 @@
-from __future__ import division, print_function, absolute_import
 
 import numpy as np
 import numpy.testing as npt
 from dipy.reconst.recspeed import (local_maxima, remove_similar_vertices,
                                    search_descending)
-from dipy.data import get_sphere, get_data
+from dipy.data import default_sphere
 from dipy.core.sphere import unique_edges, HemiSphere
 from dipy.sims.voxel import all_tensor_evecs
 
 
 def test_local_maxima():
-    sphere = get_sphere('symmetric724')
+    sphere = default_sphere
     vertices, faces = sphere.vertices, sphere.faces
     edges = unique_edges(faces)
 
@@ -24,10 +23,10 @@ def test_local_maxima():
     odf = np.zeros(len(vertices))
     odf[1] = 1.
     odf[143] = 143.
-    odf[505] = 505.
+    odf[361] = 361.
     peak_values, peak_index = local_maxima(odf, edges)
-    npt.assert_array_equal(peak_values, [505, 143, 1])
-    npt.assert_array_equal(peak_index, [505, 143, 1])
+    npt.assert_array_equal(peak_values, [361, 143, 1])
+    npt.assert_array_equal(peak_index, [361, 143, 1])
 
     # Check that neighboring points can both be peaks
     odf = np.zeros(len(vertices))
@@ -139,5 +138,4 @@ def test_search_descending():
 
 
 if __name__ == '__main__':
-    import nose
-    nose.runmodule()
+    npt.run_module_suite()
