@@ -14,6 +14,9 @@ from dipy.align.streamlinear import (StreamlineLinearRegistration,
                                      BundleMinDistanceAsymmetricMetric)
 
 from dipy.tracking.streamline import Streamlines, length
+
+from dipy.utils.deprecator import deprecated_params
+
 from nibabel.affines import apply_affine
 
 
@@ -73,8 +76,8 @@ def bundle_adjacency(dtracks0, dtracks1, threshold):
             pair21.append((i, j))
 
     pair21 = np.array(pair21)
-    A = len(pair12) / np.float(len(dtracks0))
-    B = len(pair21) / np.float(len(dtracks1))
+    A = len(pair12) / float(len(dtracks0))
+    B = len(pair21) / float(len(dtracks1))
     res = 0.5 * (A + B)
     return res
 
@@ -179,7 +182,7 @@ def bundle_shape_similarity(bundle1, bundle2, rng, clust_thr=[5, 3, 1.5],
     References
     ----------
     .. [Chandio2020] Chandio, B.Q., Risacher, S.L., Pestilli, F., Bullock, D.,
-    Yeh, FC., Koudoro, S., Rokem, A., Harezlack, J., and Garyfallidis, E.
+    Yeh, FC., Koudoro, S., Rokem, A., Harezlak, J., and Garyfallidis, E.
     Bundle analytics, a computational framework for investigating the
     shapes and profiles of brain pathways across populations.
     Sci Rep 10, 17149 (2020)
@@ -318,11 +321,13 @@ class RecoBundles(object):
                         % (self.nb_centroids,))
             logger.info(' Total duration %0.3f sec. \n' % (time() - t,))
 
+    @deprecated_params('slr_num_threads', 'num_threads', since='1.4',
+                       until='1.5')
     def recognize(self, model_bundle, model_clust_thr,
                   reduction_thr=10,
                   reduction_distance='mdf',
                   slr=True,
-                  slr_num_threads=None,
+                  num_threads=None,
                   slr_metric=None,
                   slr_x0=None,
                   slr_bounds=None,
@@ -335,26 +340,69 @@ class RecoBundles(object):
         Parameters
         ----------
         model_bundle : Streamlines
+            model bundle streamlines used as a reference to extract similar
+            streamlines from input tractogram
         model_clust_thr : float
-        reduction_thr : float
-        reduction_distance : string
-            mdf or mam (default mdf)
-        slr : bool
+            MDF distance threshold for the model bundles
+        reduction_thr : float, optional
+            Reduce search space in the target tractogram by (mm) (default 10)
+        reduction_distance : string, optional
+            Reduction distance type can be mdf or mam (default mdf)
+        slr : bool, optional
             Use Streamline-based Linear Registration (SLR) locally
             (default True)
+        num_threads : int, optional
+            Number of threads to be used for OpenMP parallelization. If None
+            (default) the value of OMP_NUM_THREADS environment variable is used
+            if it is set, otherwise all available threads are used. If < 0 the
+            maximal number of threads minus |num_threads + 1| is used (enter -1
+            to use as many threads as possible). 0 raises an error.
         slr_metric : BundleMinDistanceMetric
-        slr_x0 : array
+        slr_x0 : array or int or str, optional
+            Transformation allowed. translation, rigid, similarity or scaling
+            Initial parametrization for the optimization.
+
+            If 1D array with:
+                a) 6 elements then only rigid registration is performed with
+                the 3 first elements for translation and 3 for rotation.
+                b) 7 elements also isotropic scaling is performed (similarity).
+                c) 12 elements then translation, rotation (in degrees),
+                scaling and shearing are performed (affine).
+
+                Here is an example of x0 with 12 elements:
+                ``x0=np.array([0, 10, 0, 40, 0, 0, 2., 1.5, 1, 0.1, -0.5, 0])``
+
+                This has translation (0, 10, 0), rotation (40, 0, 0) in
+                degrees, scaling (2., 1.5, 1) and shearing (0.1, -0.5, 0).
+
+            If int:
+                a) 6
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0])``
+                b) 7
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1.])``
+                c) 12
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1., 1., 1, 0, 0, 0])``
+
+            If str:
+                a) "rigid"
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0])``
+                b) "similarity"
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1.])``
+                c) "affine"
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1., 1., 1, 0, 0, 0])
             (default None)
-        slr_bounds : array
+        slr_bounds : array, optional
             (default None)
-        slr_select : tuple
+        slr_select : tuple, optional
             Select the number of streamlines from model to neirborhood of
             model to perform the local SLR.
-        slr_method : string
-            Optimization method (default 'L-BFGS-B')
-        pruning_thr : float
-        pruning_distance : string
-            MDF ('mdf') and MAM ('mam')
+        slr_method : string, optional
+            Optimization method 'L_BFGS_B' or 'Powell' optimizers can be used.
+            (default 'L-BFGS-B')
+        pruning_thr : float, optional
+            Pruning after reducing the search space (default 5).
+        pruning_distance : string, optional
+            Pruning distance type can be mdf or mam (default mdf)
 
         Returns
         -------
@@ -395,7 +443,7 @@ class RecoBundles(object):
                 select_model=slr_select[0],
                 select_target=slr_select[1],
                 method=slr_method,
-                num_threads=slr_num_threads)
+                num_threads=num_threads)
         else:
             transf_streamlines = neighb_streamlines
 
@@ -427,20 +475,58 @@ class RecoBundles(object):
         first ouput of recobundle by applying second local slr (optional),
         and second pruning. This method is useful when we are dealing with
         noisy data or when we want to extract small tracks from tractograms.
+        This time, search space is created using pruned bundle and not model
+        bundle.
 
         Parameters
         ----------
         model_bundle : Streamlines
+            model bundle streamlines used as a reference to extract similar
+            streamlines from input tractogram
         pruned_streamlines : Streamlines
+            Recognized bundle from target tractogram by RecoBundles.
         model_clust_thr : float
+            MDF distance threshold for the model bundles
         reduction_thr : float
+            Reduce search space by (mm) (default 14)
         reduction_distance : string
-            mdf or mam (default mam)
+            Reduction distance type can be mdf or mam (default mdf)
         slr : bool
             Use Streamline-based Linear Registration (SLR) locally
             (default True)
         slr_metric : BundleMinDistanceMetric
-        slr_x0 : array
+        slr_x0 : array or int or str
+            Transformation allowed. translation, rigid, similarity or scaling
+            Initial parametrization for the optimization.
+
+            If 1D array with:
+                a) 6 elements then only rigid registration is performed with
+                the 3 first elements for translation and 3 for rotation.
+                b) 7 elements also isotropic scaling is performed (similarity).
+                c) 12 elements then translation, rotation (in degrees),
+                scaling and shearing are performed (affine).
+
+                Here is an example of x0 with 12 elements:
+                ``x0=np.array([0, 10, 0, 40, 0, 0, 2., 1.5, 1, 0.1, -0.5, 0])``
+
+                This has translation (0, 10, 0), rotation (40, 0, 0) in
+                degrees, scaling (2., 1.5, 1) and shearing (0.1, -0.5, 0).
+
+            If int:
+                a) 6
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0])``
+                b) 7
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1.])``
+                c) 12
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1., 1., 1, 0, 0, 0])``
+
+            If str:
+                a) "rigid"
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0])``
+                b) "similarity"
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1.])``
+                c) "affine"
+                    ``x0 = np.array([0, 0, 0, 0, 0, 0, 1., 1., 1, 0, 0, 0])
             (default None)
         slr_bounds : array
             (default None)
@@ -448,10 +534,12 @@ class RecoBundles(object):
             Select the number of streamlines from model to neirborhood of
             model to perform the local SLR.
         slr_method : string
-            Optimization method (default 'L-BFGS-B')
+            Optimization method 'L_BFGS_B' or 'Powell' optimizers can be used.
+            (default 'L-BFGS-B')
         pruning_thr : float
+            Pruning after reducing the search space (default 6).
         pruning_distance : string
-            MDF ('mdf') and MAM ('mam')
+            Pruning distance type can be mdf or mam (default mdf)
 
         Returns
         -------
@@ -467,7 +555,7 @@ class RecoBundles(object):
             clustering, Neuroimage, 2017.
 
         .. [Chandio2020] Chandio, B.Q., Risacher, S.L., Pestilli, F.,
-        Bullock, D., Yeh, FC., Koudoro, S., Rokem, A., Harezlack, J., and
+        Bullock, D., Yeh, FC., Koudoro, S., Rokem, A., Harezlak, J., and
         Garyfallidis, E. Bundle analytics, a computational framework for
         investigating the shapes and profiles of brain pathways across
         populations. Sci Rep 10, 17149 (2020)
