@@ -1,7 +1,6 @@
 import warnings
 
 import numpy as np
-import nibabel as nib
 from scipy.ndimage import generate_binary_structure, binary_dilation
 from scipy.ndimage.filters import median_filter
 
@@ -10,8 +9,10 @@ from dipy.segment.mask import (otsu, bounding_box, crop, applymask,
 
 from numpy.testing import (assert_equal,
                            assert_almost_equal,
+                           assert_raises,
                            run_module_suite)
-from dipy.data import get_data
+from dipy.data import get_fnames
+from dipy.io.image import load_nifti_data
 
 
 def test_mask():
@@ -36,15 +37,16 @@ def test_mask():
     assert_equal(final, initial)
 
     # Test multi_median.
-    median_test = np.arange(25).reshape(5, 5)
-    median_control = median_test.copy()
-    medianradius = 3
-    median_test = multi_median(median_test, medianradius, 3)
+    img = np.arange(25).reshape(5, 5)
+    img_copy = img.copy()
+    medianradius = 2
+    median_test = multi_median(img, medianradius, 3)
+    assert_equal(img, img_copy)
 
-    medarr = np.ones_like(median_control.shape) * ((medianradius * 2) + 1)
-    median_filter(median_control, medarr, output=median_control)
-    median_filter(median_control, medarr, output=median_control)
-    median_filter(median_control, medarr, output=median_control)
+    medarr = np.ones_like(img.shape) * ((medianradius * 2) + 1)
+    median_control = median_filter(img, medarr)
+    median_control = median_filter(median_control, medarr)
+    median_control = median_filter(median_control, medarr)
     assert_equal(median_test, median_control)
 
 
@@ -83,9 +85,8 @@ def test_bounding_box():
 
 
 def test_median_otsu():
-    fname = get_data('S0_10')
-    img = nib.load(fname)
-    data = img.get_data()
+    fname = get_fnames('S0_10')
+    data = load_nifti_data(fname)
     data = np.squeeze(data.astype('f8'))
     dummy_mask = data > data.mean()
     data_masked, mask = median_otsu(data, median_radius=3, numpass=2,
@@ -111,6 +112,9 @@ def test_median_otsu():
                            dilate=2)
     assert_equal(mask3.sum() < mask4.sum(), True)
 
+    # For 4D volumes, can't call without vol_idx input:
+    assert_raises(ValueError, median_otsu, data2)
+
 
 if __name__ == '__main__':
     run_module_suite()
