@@ -4,8 +4,7 @@
 
 Run scripts and check outputs
 """
-'''
-from __future__ import division, print_function, absolute_import
+"""
 
 import glob
 import os
@@ -13,13 +12,14 @@ import shutil
 
 from os.path import (dirname, join as pjoin, abspath)
 
-from nose.tools import assert_true, assert_false, assert_equal
+from dipy.testing import assert_true, assert_false
 import numpy.testing as nt
+import pytest
 
 import nibabel as nib
 from nibabel.tmpdirs import InTemporaryDirectory
 
-from dipy.data import get_data
+from dipy.data import get_fnames
 
 # Quickbundles command-line requires matplotlib:
 try:
@@ -42,33 +42,33 @@ def test_dipy_peak_extraction():
     # test dipy_peak_extraction script
     cmd = 'dipy_peak_extraction'
     code, stdout, stderr = run_command(cmd, check_code=False)
-    assert_equal(code, 2)
+    npt.assert_equal(code, 2)
 
 
 def test_dipy_fit_tensor():
     # test dipy_fit_tensor script
     cmd = 'dipy_fit_tensor'
     code, stdout, stderr = run_command(cmd, check_code=False)
-    assert_equal(code, 2)
+    npt.assert_equal(code, 2)
 
 
 def test_dipy_sh_estimate():
     # test dipy_sh_estimate script
     cmd = 'dipy_sh_estimate'
     code, stdout, stderr = run_command(cmd, check_code=False)
-    assert_equal(code, 2)
+    npt.assert_equal(code, 2)
 
 
 def assert_image_shape_affine(filename, shape, affine):
     assert_true(os.path.isfile(filename))
     image = nib.load(filename)
-    assert_equal(image.shape, shape)
+    npt.assert_equal(image.shape, shape)
     nt.assert_array_almost_equal(image.affine, affine)
 
 
 def test_dipy_fit_tensor_again():
     with InTemporaryDirectory():
-        dwi, bval, bvec = get_data("small_25")
+        dwi, bval, bvec = get_fnames("small_25")
         # Copy data to tmp directory
         shutil.copyfile(dwi, "small_25.nii.gz")
         shutil.copyfile(bval, "small_25.bval")
@@ -76,7 +76,7 @@ def test_dipy_fit_tensor_again():
         # Call script
         cmd = ["dipy_fit_tensor", "--mask=none", "small_25.nii.gz"]
         out = run_command(cmd)
-        assert_equal(out[0], 0)
+        npt.assert_equal(out[0], 0)
         # Get expected values
         img = nib.load("small_25.nii.gz")
         affine = img.affine
@@ -90,7 +90,7 @@ def test_dipy_fit_tensor_again():
         assert_image_shape_affine("small_25_rd.nii.gz", shape, affine)
 
     with InTemporaryDirectory():
-        dwi, bval, bvec = get_data("small_25")
+        dwi, bval, bvec = get_fnames("small_25")
         # Copy data to tmp directory
         shutil.copyfile(dwi, "small_25.nii.gz")
         shutil.copyfile(bval, "small_25.bval")
@@ -99,7 +99,7 @@ def test_dipy_fit_tensor_again():
         cmd = ["dipy_fit_tensor", "--save-tensor",
                "--mask=none", "small_25.nii.gz"]
         out = run_command(cmd)
-        assert_equal(out[0], 0)
+        npt.assert_equal(out[0], 0)
         # Get expected values
         img = nib.load("small_25.nii.gz")
         affine = img.affine
@@ -118,16 +118,16 @@ def test_dipy_fit_tensor_again():
                                   affine)
 
 
-@nt.dec.skipif(no_mpl)
+@pytest.mark.skipif(no_mpl)
 def test_qb_commandline():
     with InTemporaryDirectory():
-        tracks_file = get_data('fornix')
+        tracks_file = get_fnames('fornix')
         cmd = ["dipy_quickbundles", tracks_file, '--pkl_file', 'mypickle.pkl',
                '--out_file', 'tracks300.trk']
         out = run_command(cmd)
-        assert_equal(out[0], 0)
+        npt.assert_equal(out[0], 0)
 
-@nt.dec.skipif(no_mpl)
+@pytest.mark.skipif(no_mpl)
 def test_qb_commandline_output_path_handling():
     with InTemporaryDirectory():
         # Create temporary subdirectory for input and for output
@@ -135,17 +135,17 @@ def test_qb_commandline_output_path_handling():
         os.mkdir('output')
 
         os.chdir('work')
-        tracks_file = get_data('fornix')
+        tracks_file = get_fnames('fornix')
 
         # Need to specify an output directory with a "../" style path
         # to trigger old bug.
         cmd = ["dipy_quickbundles", tracks_file, '--pkl_file', 'mypickle.pkl',
                '--out_file', os.path.join('..', 'output', 'tracks300.trk')]
         out = run_command(cmd)
-        assert_equal(out[0], 0)
+        npt.assert_equal(out[0], 0)
 
         # Make sure the files were created in the output directory
         os.chdir('../')
         output_files_list = glob.glob('output/tracks300_*.trk')
         assert_true(output_files_list)
-'''
+"""
