@@ -1,8 +1,8 @@
 
 import numpy as np
-from nose.tools import assert_true, assert_false, \
-     assert_equal, assert_raises
-from numpy.testing import assert_array_equal, assert_array_almost_equal
+from dipy.testing import assert_true, assert_false
+from numpy.testing import (assert_array_equal, assert_array_almost_equal,
+                           assert_equal, assert_raises)
 import dipy.tracking.vox2track as tvo
 
 
