@@ -4,8 +4,8 @@
 import os
 from dipy.utils.omp import (cpu_count, thread_count, default_threads,
                             _set_omp_threads, _restore_omp_threads,
-                            have_openmp)
-from numpy.testing import assert_equal, run_module_suite
+                            have_openmp, determine_num_threads)
+from numpy.testing import assert_equal, assert_raises, run_module_suite
 
 
 def test_set_omp_threads():
@@ -40,6 +40,28 @@ def test_default_threads():
     assert_equal(default_threads, expected_threads)
 
 
+def test_determine_num_threads():
+    # 0 should raise an error
+    assert_raises(ValueError, determine_num_threads, 0)
+
+    # A string should raise an error
+    assert_raises(TypeError, determine_num_threads, "1")
+
+    # 1 should be 1
+    assert_equal(determine_num_threads(1), 1)
+
+    # A positive integer should not change
+    assert_equal(determine_num_threads(4), 4)
+
+    # A big negative number should be 1
+    assert_equal(determine_num_threads(-10000), 1)
+
+    # -2 should be one less than -1 (if there are more than 1 cores)
+    if determine_num_threads(-1) > 1:
+        assert_equal(determine_num_threads(-1),
+                     determine_num_threads(-2) + 1)
+
+
 if __name__ == '__main__':
 
     run_module_suite()
