@@ -20,7 +20,7 @@ def is_tripwire(obj):
         obj.any_attribute
     except TripWireError:
         return True
-    except:
+    except Exception:
         pass
     return False
 
@@ -46,9 +46,9 @@ class TripWire(object):
         self._msg = msg
 
     def __getattr__(self, attr_name):
-        ''' Raise informative error accessing attributes '''
+        """ Raise informative error accessing attributes """
         raise TripWireError(self._msg)
 
     def __call__(self, *args, **kwargs):
-        ''' Raise informative error while calling '''
+        """ Raise informative error while calling """
         raise TripWireError(self._msg)
