@@ -18,7 +18,38 @@ def _tile_plot(imgs, titles, **kwargs):
     return fig
 
 
-def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None):
+def simple_plot(file_name, title, x, y, xlabel, ylabel):
+    """ Saves the simple plot with given x and y values
+
+    Parameters
+    ----------
+    file_name : string
+        file name for saving the plot
+    title : string
+        title of the plot
+    x : integer list
+        x-axis values to be plotted
+    y : integer list
+        y-axis values to be plotted
+    xlabel : string
+        label for x-axis
+    ylable : string
+        label for y-axis
+
+    """
+
+    plt.plot(x, y)
+    axes = plt.gca()
+    axes.set_ylim([0, 4])
+    plt.xlabel(xlabel)
+    plt.ylabel(ylabel)
+    plt.title(title)
+
+    plt.savefig(file_name)
+    plt.clf()
+
+
+def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None, **fig_kwargs):
     r""" Plot two images one on top of the other using red and green channels.
 
     Creates a figure containing three images: the first image to the left
@@ -48,6 +79,7 @@ def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None):
     fname : string (optional)
         the file name to write the resulting figure. If None (default), the
         image is not saved.
+    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
     """
     # Normalize the input images to [0,255]
     img0 = 255 * ((img0 - img0.min()) / (img0.max() - img0.min()))
@@ -70,7 +102,7 @@ def overlay_images(img0, img1, title0='', title_mid='', title1='', fname=None):
 
     # If a file name was given, save the figure
     if fname is not None:
-        fig.savefig(fname, bbox_inches='tight')
+        fig.savefig(fname, bbox_inches='tight', **fig_kwargs)
 
     return fig
 
@@ -121,7 +153,7 @@ def draw_lattice_2d(nrows, ncols, delta):
 def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
                               direct_grid_shape=None, direct_grid2world=-1,
                               inverse_grid_shape=None, inverse_grid2world=-1,
-                              show_figure=True):
+                              show_figure=True, **fig_kwargs):
     r"""Draw the effect of warping a regular lattice by a diffeomorphic map.
 
     Draws a diffeomorphic map by showing the effect of the deformation on a
@@ -167,51 +199,52 @@ def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
         inverse_grid_shape (in general, if users specify an inverse_grid_shape,
         they should also specify inverse_grid2world).
     show_figure : bool, optional
-        if True (default), the deformed grids will be ploted using matplotlib,
+        if True (default), the deformed grids will be plotted using matplotlib,
         else the grids are just returned
+    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
 
     Returns
     -------
     warped_forward : array
-        Image with grid showing the effect of transforming the moving image to
-        the static image.  Shape will be `direct_grid_shape` if specified,
+        Image with the grid showing the effect of transforming the moving image to
+        the static image.  The shape will be `direct_grid_shape` if specified,
         otherwise the shape of the static image.
     warped_backward : array
-        Image with grid showing the effect of transforming the static image to
+        Image with the grid showing the effect of transforming the static image to
         the moving image.  Shape will be `inverse_grid_shape` if specified,
         otherwise the shape of the moving image.
 
-    Note
-    ----
+    Notes
+    ------
     The default value for the affine transformation is "-1" to handle the case
     in which the user provides "None" as input meaning "identity". If we used
     None as default, we wouldn't know if the user specifically wants to use
     the identity (specifically passing None) or if it was left unspecified,
-    meaning to use the apropriate default matrix.
+    meaning to use the appropriate default matrix.
     """
     if mapping.is_inverse:
         # By default, direct_grid_shape is the codomain grid
         if direct_grid_shape is None:
             direct_grid_shape = mapping.codomain_shape
-        if direct_grid2world is -1:
+        if direct_grid2world == -1:
             direct_grid2world = mapping.codomain_grid2world
 
         # By default, the inverse grid is the domain grid
         if inverse_grid_shape is None:
             inverse_grid_shape = mapping.domain_shape
-        if inverse_grid2world is -1:
+        if inverse_grid2world == -1:
             inverse_grid2world = mapping.domain_grid2world
     else:
         # Now by default, direct_grid_shape is the mapping's input grid
         if direct_grid_shape is None:
             direct_grid_shape = mapping.domain_shape
-        if direct_grid2world is -1:
+        if direct_grid2world == -1:
             direct_grid2world = mapping.domain_grid2world
 
         # By default, the output grid is the mapping's domain grid
         if inverse_grid_shape is None:
             inverse_grid_shape = mapping.codomain_shape
-        if inverse_grid2world is -1:
+        if inverse_grid2world == -1:
             inverse_grid2world = mapping.codomain_grid2world
 
     # The world-to-image (image = drawn lattice on the output grid)
@@ -262,16 +295,16 @@ def plot_2d_diffeomorphic_map(mapping, delta=10, fname=None,
 
         # Finally, save the figure to disk
         if fname is not None:
-            plt.savefig(fname, bbox_inches='tight')
+            plt.savefig(fname, bbox_inches='tight', **fig_kwargs)
 
     # Return the deformed grids
     return warped_forward, warped_backward
 
 
-def plot_slices(V, slice_indices=None, fname=None):
+def plot_slices(V, slice_indices=None, fname=None, **fig_kwargs):
     r"""Plot 3 slices from the given volume: 1 sagital, 1 coronal and 1 axial
 
-    Creates a figure showing the axial, coronal and sagital slices at the
+    Creates a figure showing the axial, coronal and sagittal slices at the
     requested positions of the given volume. The requested slices are specified
     by slice_indices.
 
@@ -287,6 +320,7 @@ def plot_slices(V, slice_indices=None, fname=None):
     fname : string (optional)
         the name of the file to save the figure to. If None (default), the
         figure is not saved to disk.
+    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
     """
     if slice_indices is None:
         slice_indices = np.array(V.shape) // 2
@@ -306,13 +340,13 @@ def plot_slices(V, slice_indices=None, fname=None):
 
     # Save the figure if requested
     if fname is not None:
-        fig.savefig(fname, bbox_inches='tight')
+        fig.savefig(fname, bbox_inches='tight', **fig_kwargs)
 
     return fig
 
 
 def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
-                   rtitle='Right', fname=None):
+                   rtitle='Right', fname=None, **fig_kwargs):
     r"""Plot three overlaid slices from the given volumes.
 
     Creates a figure containing three images: the gray scale k-th slice of
@@ -326,7 +360,7 @@ def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
     Parameters
     ----------
     L : array, shape (S, R, C)
-        the first volume to extract the slice from, plottet to the left
+        the first volume to extract the slice from plotted to the left
     R : array, shape (S, R, C)
         the second volume to extract the slice from, plotted to the right
     slice_index : int (optional)
@@ -336,14 +370,15 @@ def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
         the type of slice to be extracted:
         0=sagital, 1=coronal (default), 2=axial.
     ltitle : string (optional)
-        the string to be written as title of the left image. By default,
+        the string to be written as the title of the left image. By default,
         no title is displayed.
     rtitle : string (optional)
-        the string to be written as title of the right image. By default,
+        the string to be written as the title of the right image. By default,
         no title is displayed.
     fname : string (optional)
         the name of the file to write the image to. If None (default), the
         figure is not saved to disk.
+    fig_kwargs: extra parameters for saving figure, e.g. `dpi=300`.
     """
 
     # Normalize the intensities to [0,255]
@@ -355,19 +390,19 @@ def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
 
     # Create the color image to draw the overlapped slices into, and extract
     # the slices (note the transpositions)
-    if slice_type is 0:
+    if slice_type == 0:
         if slice_index is None:
             slice_index = sh[0] // 2
         colorImage = np.zeros(shape=(sh[2], sh[1], 3), dtype=np.uint8)
         ll = np.asarray(L[slice_index, :, :]).astype(np.uint8).T
         rr = np.asarray(R[slice_index, :, :]).astype(np.uint8).T
-    elif slice_type is 1:
+    elif slice_type == 1:
         if slice_index is None:
             slice_index = sh[1] // 2
         colorImage = np.zeros(shape=(sh[2], sh[0], 3), dtype=np.uint8)
         ll = np.asarray(L[:, slice_index, :]).astype(np.uint8).T
         rr = np.asarray(R[:, slice_index, :]).astype(np.uint8).T
-    elif slice_type is 2:
+    elif slice_type == 2:
         if slice_index is None:
             slice_index = sh[2] // 2
         colorImage = np.zeros(shape=(sh[1], sh[0], 3), dtype=np.uint8)
@@ -390,6 +425,6 @@ def overlay_slices(L, R, slice_index=None, slice_type=1, ltitle='Left',
 
     # Save the figure to disk, if requested
     if fname is not None:
-        fig.savefig(fname, bbox_inches='tight')
+        fig.savefig(fname, bbox_inches='tight', **fig_kwargs)
 
     return fig
