@@ -28,8 +28,6 @@ IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 """
 
-from __future__ import division, absolute_import, print_function
-
 import re
 import textwrap
 from warnings import warn
@@ -128,6 +126,7 @@ class NumpyDocString(object):
             'Parameters': [],
             'Outputs': [],
             'Returns': [],
+            'Yields': [],
             'Raises': [],
             'Warns': [],
             'Other Parameters': [],
