@@ -27,6 +27,8 @@ from dipy.reconst.ivim import IvimModel
 
 from dipy.reconst import mapmri
 
+from dipy.utils.deprecator import deprecated_params
+
 
 class ReconstMAPMRIFlow(Workflow):
     @classmethod
@@ -68,49 +70,46 @@ class ReconstMAPMRIFlow(Workflow):
             Big delta value used in generation of gradient table of provided
             bval and bvec.
         b0_threshold : float, optional
-            Threshold used to find b=0 directions (default 0.0)
+            Threshold used to find b0 volumes.
         laplacian : bool, optional
-            Regularize using the Laplacian of the MAP-MRI basis (default True)
+            Regularize using the Laplacian of the MAP-MRI basis.
         positivity : bool, optional
-            Constrain the propagator to be positive. (default True)
+            Constrain the propagator to be positive.
         bval_threshold : float, optional
             Sets the b-value threshold to be used in the scale factor
             estimation. In order for the estimated non-Gaussianity to have
             meaning this value should set to a lower value (b<2000 s/mm^2)
             such that the scale factors are estimated on signal points that
             reasonably represent the spins at Gaussian diffusion.
-            (default: 2000)
         save_metrics : variable string, optional
             List of metrics to save.
             Possible values: rtop, laplacian_signal, msd, qiv, rtap, rtpp,
             ng, perng, parng
-            (default: [] (all))
         laplacian_weighting : float, optional
             Weighting value used in fitting the MAPMRI model in the Laplacian
-            and both model types. (default: 0.05)
+            and both model types.
         radial_order : unsigned int, optional
-            Even value used to set the order of the basis
-            (default: 6)
+            Even value used to set the order of the basis.
         out_dir : string, optional
-            Output directory (default: input file directory)
+            Output directory. (default: current directory)
         out_rtop : string, optional
-            Name of the rtop to be saved
+            Name of the rtop to be saved.
         out_lapnorm : string, optional
-            Name of the norm of Laplacian signal to be saved
+            Name of the norm of Laplacian signal to be saved.
         out_msd : string, optional
-            Name of the msd to be saved
+            Name of the msd to be saved.
         out_qiv : string, optional
-            Name of the qiv to be saved
+            Name of the qiv to be saved.
         out_rtap : string, optional
-            Name of the rtap to be saved
+            Name of the rtap to be saved.
         out_rtpp : string, optional
-            Name of the rtpp to be saved
+            Name of the rtpp to be saved.
         out_ng : string, optional
-            Name of the Non-Gaussianity to be saved
+            Name of the Non-Gaussianity to be saved.
         out_perng :  string, optional
-            Name of the Non-Gaussianity perpendicular to be saved
+            Name of the Non-Gaussianity perpendicular to be saved.
         out_parng : string, optional
-            Name of the Non-Gaussianity parallel to be saved
+            Name of the Non-Gaussianity parallel to be saved.
         """
         io_it = self.get_io_iterator()
         for (dwi, bval, bvec, out_rtop, out_lapnorm, out_msd, out_qiv,
@@ -250,18 +249,17 @@ class ReconstDtiFlow(Workflow):
             Path to the input masks. This path may contain wildcards to use
             multiple masks at once.
         b0_threshold : float, optional
-            Threshold used to find b=0 directions (default 0.0)
+            Threshold used to find b0 volumes.
         bvecs_tol : float, optional
             Threshold used to check that norm(bvec) = 1 +/- bvecs_tol
-            b-vectors are unit vectors (default 0.01)
+            b-vectors are unit vectors.
         save_metrics : variable string, optional
             List of metrics to save.
             Possible values: fa, ga, rgb, md, ad, rd, mode, tensor, evec, eval
-            (default [] (all))
         out_dir : string, optional
-            Output directory (default input file directory)
+            Output directory. (default current directory)
         out_tensor : string, optional
-            Name of the tensors volume to be saved (default 'tensors.nii.gz').
+            Name of the tensors volume to be saved.
             Per default, this will be saved following the nifti standard:
             with the tensor elements as Dxx, Dxy, Dyy, Dxz, Dyz, Dzz on the
             last (5th) dimension of the volume (shape: (i, j, k, 1, 6)). If
@@ -270,35 +268,29 @@ class ReconstDtiFlow(Workflow):
             4-dimensional volume (shape (i, j, k, 6)) with Dxx, Dxy, Dxz, Dyy,
             Dyz, Dzz on the last dimension.
         out_fa : string, optional
-            Name of the fractional anisotropy volume to be saved
-            (default 'fa.nii.gz')
+            Name of the fractional anisotropy volume to be saved.
         out_ga : string, optional
-            Name of the geodesic anisotropy volume to be saved
-            (default 'ga.nii.gz')
+            Name of the geodesic anisotropy volume to be saved.
         out_rgb : string, optional
-            Name of the color fa volume to be saved (default 'rgb.nii.gz')
+            Name of the color fa volume to be saved.
         out_md : string, optional
-            Name of the mean diffusivity volume to be saved
-            (default 'md.nii.gz')
+            Name of the mean diffusivity volume to be saved.
         out_ad : string, optional
-            Name of the axial diffusivity volume to be saved
-            (default 'ad.nii.gz')
+            Name of the axial diffusivity volume to be saved.
         out_rd : string, optional
-            Name of the radial diffusivity volume to be saved
-            (default 'rd.nii.gz')
+            Name of the radial diffusivity volume to be saved.
         out_mode : string, optional
-            Name of the mode volume to be saved (default 'mode.nii.gz')
+            Name of the mode volume to be saved.
         out_evec : string, optional
-            Name of the eigenvectors volume to be saved
-            (default 'evecs.nii.gz')
+            Name of the eigenvectors volume to be saved.
         out_eval : string, optional
-            Name of the eigenvalues to be saved (default 'evals.nii.gz')
+            Name of the eigenvalues to be saved.
         nifti_tensor : bool, optional
             Whether the tensor is saved in the standard Nifti format or in an
             alternate format
             that is used by other software (e.g., FSL): a
             4-dimensional volume (shape (i, j, k, 6)) with
-            Dxx, Dxy, Dxz, Dyy, Dyz, Dzz on the last dimension. Default: True
+            Dxx, Dxy, Dxz, Dyy, Dyz, Dzz on the last dimension.
 
         References
         ----------
@@ -327,7 +319,7 @@ class ReconstDtiFlow(Workflow):
             data, affine = load_nifti(dwi)
 
             if mask is not None:
-                mask = load_nifti_data(mask).astype(np.bool)
+                mask = load_nifti_data(mask).astype(bool)
 
             tenfit, _ = self.get_fitted_tensor(data, mask, bval, bvec,
                                                b0_threshold, bvecs_tol)
@@ -415,10 +407,12 @@ class ReconstCSDFlow(Workflow):
     def get_short_name(cls):
         return 'csd'
 
+    @deprecated_params('nbr_processes', 'num_processes', since='1.4',
+                       until='1.5')
     def run(self, input_files, bvalues_files, bvectors_files, mask_files,
             b0_threshold=50.0, bvecs_tol=0.01, roi_center=None, roi_radii=10,
             fa_thr=0.7, frf=None, extract_pam_values=False, sh_order=8,
-            odf_to_sh_order=8, parallel=False, nbr_processes=None,
+            odf_to_sh_order=8, parallel=False, num_processes=None,
             out_dir='',
             out_pam='peaks.pam5', out_shm='shm.nii.gz',
             out_peaks_dir='peaks_dirs.nii.gz',
@@ -441,53 +435,50 @@ class ReconstCSDFlow(Workflow):
             Path to the input masks. This path may contain wildcards to use
             multiple masks at once. (default: No mask used)
         b0_threshold : float, optional
-            Threshold used to find b=0 directions
+            Threshold used to find b0 volumes.
         bvecs_tol : float, optional
-            Bvecs should be unit vectors. (default:0.01)
+            Bvecs should be unit vectors.
         roi_center : variable int, optional
             Center of ROI in data. If center is None, it is assumed that it is
-            the center of the volume with shape `data.shape[:3]` (default None)
+            the center of the volume with shape `data.shape[:3]`.
         roi_radii : int or array-like, optional
-            radii of cuboid ROI in voxels (default 10)
+            radii of cuboid ROI in voxels.
         fa_thr : float, optional
-            FA threshold for calculating the response function (default 0.7)
+            FA threshold for calculating the response function.
         frf : variable float, optional
             Fiber response function can be for example inputed as 15 4 4
             (from the command line) or [15, 4, 4] from a Python script to be
             converted to float and multiplied by 10**-4 . If None
-            the fiber response function will be computed automatically
-            (default: None).
+            the fiber response function will be computed automatically.
         extract_pam_values : bool, optional
             Save or not to save pam volumes as single nifti files.
         sh_order : int, optional
-            Spherical harmonics order (default 6) used in the CSA fit.
+            Spherical harmonics order used in the CSA fit.
         odf_to_sh_order : int, optional
             Spherical harmonics order used for peak_from_model to compress
-            the ODF to spherical harmonics coefficients (default 8)
+            the ODF to spherical harmonics coefficients.
         parallel : bool, optional
             Whether to use parallelization in peak-finding during the
-            calibration procedure. Default: False
-        nbr_processes : int, optional
+            calibration procedure.
+        num_processes : int, optional
             If `parallel` is True, the number of subprocesses to use
-            (default multiprocessing.cpu_count()).
+            (default multiprocessing.cpu_count()). If < 0 the maximal number
+            of cores minus |num_processes + 1| is used (enter -1 to use as
+            many cores as possible). 0 raises an error.
         out_dir : string, optional
-            Output directory (default input file directory)
+            Output directory. (default current directory)
         out_pam : string, optional
-            Name of the peaks volume to be saved (default 'peaks.pam5')
+            Name of the peaks volume to be saved.
         out_shm : string, optional
-            Name of the spherical harmonics volume to be saved
-            (default 'shm.nii.gz')
+            Name of the spherical harmonics volume to be saved.
         out_peaks_dir : string, optional
-            Name of the peaks directions volume to be saved
-            (default 'peaks_dirs.nii.gz')
+            Name of the peaks directions volume to be saved.
         out_peaks_values : string, optional
-            Name of the peaks values volume to be saved
-            (default 'peaks_values.nii.gz')
+            Name of the peaks values volume to be saved.
         out_peaks_indices : string, optional
-            Name of the peaks indices volume to be saved
-            (default 'peaks_indices.nii.gz')
+            Name of the peaks indices volume to be saved.
         out_gfa : string, optional
-            Name of the generalized FA volume to be saved (default 'gfa.nii.gz')
+            Name of the generalized FA volume to be saved.
 
 
         References
@@ -512,7 +503,7 @@ class ReconstCSDFlow(Workflow):
                      "({1}).".format(b0_threshold, bvals.min()))
             gtab = gradient_table(bvals, bvecs, b0_threshold=b0_threshold,
                                   atol=bvecs_tol)
-            mask_vol = load_nifti_data(maskfile).astype(np.bool)
+            mask_vol = load_nifti_data(maskfile).astype(bool)
 
             n_params = ((sh_order + 1) * (sh_order + 2)) / 2
             if data.shape[-1] < n_params:
@@ -568,7 +559,7 @@ class ReconstCSDFlow(Workflow):
                                          sh_order=sh_order,
                                          normalize_peaks=True,
                                          parallel=parallel,
-                                         nbr_processes=nbr_processes)
+                                         num_processes=num_processes)
             peaks_csd.affine = affine
 
             save_peaks(opam, peaks_csd)
@@ -594,9 +585,11 @@ class ReconstCSAFlow(Workflow):
     def get_short_name(cls):
         return 'csa'
 
+    @deprecated_params('nbr_processes', 'num_processes', since='1.4',
+                       until='1.5')
     def run(self, input_files, bvalues_files, bvectors_files, mask_files,
             sh_order=6, odf_to_sh_order=8, b0_threshold=50.0, bvecs_tol=0.01,
-            extract_pam_values=False, parallel=False, nbr_processes=None,
+            extract_pam_values=False, parallel=False, num_processes=None,
             out_dir='',
             out_pam='peaks.pam5', out_shm='shm.nii.gz',
             out_peaks_dir='peaks_dirs.nii.gz',
@@ -620,40 +613,38 @@ class ReconstCSAFlow(Workflow):
             Path to the input masks. This path may contain wildcards to use
             multiple masks at once. (default: No mask used)
         sh_order : int, optional
-            Spherical harmonics order (default 6) used in the CSA fit.
+            Spherical harmonics order used in the CSA fit.
         odf_to_sh_order : int, optional
             Spherical harmonics order used for peak_from_model to compress
-            the ODF to spherical harmonics coefficients (default 8)
+            the ODF to spherical harmonics coefficients.
         b0_threshold : float, optional
-            Threshold used to find b=0 directions
+            Threshold used to find b0 volumes.
         bvecs_tol : float, optional
-            Threshold used so that norm(bvec)=1 (default 0.01)
+            Threshold used so that norm(bvec)=1.
         extract_pam_values : bool, optional
-            Wheter or not to save pam volumes as single nifti files.
+            Whether or not to save pam volumes as single nifti files.
         parallel : bool, optional
             Whether to use parallelization in peak-finding during the
-            calibration procedure. Default: False
-        nbr_processes : int, optional
+            calibration procedure.
+        num_processes : int, optional
             If `parallel` is True, the number of subprocesses to use
-            (default multiprocessing.cpu_count()).
+            (default multiprocessing.cpu_count()). If < 0 the maximal number
+            of cores minus |num_processes + 1| is used (enter -1 to use as
+            many cores as possible). 0 raises an error.
         out_dir : string, optional
-            Output directory (default input file directory)
+            Output directory. (default current directory)
         out_pam : string, optional
-            Name of the peaks volume to be saved (default 'peaks.pam5')
+            Name of the peaks volume to be saved.
         out_shm : string, optional
-            Name of the spherical harmonics volume to be saved
-            (default 'shm.nii.gz')
+            Name of the spherical harmonics volume to be saved.
         out_peaks_dir : string, optional
-            Name of the peaks directions volume to be saved
-            (default 'peaks_dirs.nii.gz')
+            Name of the peaks directions volume to be saved.
         out_peaks_values : string, optional
-            Name of the peaks values volume to be saved
-            (default 'peaks_values.nii.gz')
+            Name of the peaks values volume to be saved.
         out_peaks_indices : string, optional
-            Name of the peaks indices volume to be saved
-            (default 'peaks_indices.nii.gz')
+            Name of the peaks indices volume to be saved.
         out_gfa : string, optional
-            Name of the generalized FA volume to be saved (default 'gfa.nii.gz')
+            Name of the generalized FA volume to be saved.
 
         References
         ----------
@@ -675,7 +666,7 @@ class ReconstCSAFlow(Workflow):
                      "({1}).".format(b0_threshold, bvals.min()))
             gtab = gradient_table(bvals, bvecs,
                                   b0_threshold=b0_threshold, atol=bvecs_tol)
-            mask_vol = load_nifti_data(maskfile).astype(np.bool)
+            mask_vol = load_nifti_data(maskfile).astype(bool)
 
             peaks_sphere = default_sphere
 
@@ -693,7 +684,7 @@ class ReconstCSAFlow(Workflow):
                                          sh_order=odf_to_sh_order,
                                          normalize_peaks=True,
                                          parallel=parallel,
-                                         nbr_processes=nbr_processes)
+                                         num_processes=num_processes)
             peaks_csa.affine = affine
 
             save_peaks(opam, peaks_csa)
@@ -748,49 +739,40 @@ class ReconstDkiFlow(Workflow):
             Path to the input masks. This path may contain wildcards to use
             multiple masks at once. (default: No mask used)
         b0_threshold : float, optional
-            Threshold used to find b=0 directions (default 0.0)
+            Threshold used to find b0 volumes.
         save_metrics : variable string, optional
             List of metrics to save.
             Possible values: fa, ga, rgb, md, ad, rd, mode, tensor, evec, eval
-            (default [] (all))
         out_dir : string, optional
-            Output directory (default input file directory)
+            Output directory. (default current directory)
         out_dt_tensor : string, optional
-            Name of the tensors volume to be saved
-            (default: 'dti_tensors.nii.gz')
+            Name of the tensors volume to be saved.
         out_dk_tensor : string, optional
-            Name of the tensors volume to be saved
-            (default 'dki_tensors.nii.gz')
+            Name of the tensors volume to be saved.
         out_fa : string, optional
-            Name of the fractional anisotropy volume to be saved
-            (default 'fa.nii.gz')
+            Name of the fractional anisotropy volume to be saved.
         out_ga : string, optional
-            Name of the geodesic anisotropy volume to be saved
-            (default 'ga.nii.gz')
+            Name of the geodesic anisotropy volume to be saved.
         out_rgb : string, optional
-            Name of the color fa volume to be saved (default 'rgb.nii.gz')
+            Name of the color fa volume to be saved.
         out_md : string, optional
-            Name of the mean diffusivity volume to be saved
-            (default 'md.nii.gz')
+            Name of the mean diffusivity volume to be saved.
         out_ad : string, optional
-            Name of the axial diffusivity volume to be saved
-            (default 'ad.nii.gz')
+            Name of the axial diffusivity volume to be saved.
         out_rd : string, optional
-            Name of the radial diffusivity volume to be saved
-            (default 'rd.nii.gz')
+            Name of the radial diffusivity volume to be saved.
         out_mode : string, optional
-            Name of the mode volume to be saved (default 'mode.nii.gz')
+            Name of the mode volume to be saved.
         out_evec : string, optional
-            Name of the eigenvectors volume to be saved
-            (default 'evecs.nii.gz')
+            Name of the eigenvectors volume to be saved.
         out_eval : string, optional
-            Name of the eigenvalues to be saved (default 'evals.nii.gz')
+            Name of the eigenvalues to be saved.
         out_mk : string, optional
-            Name of the mean kurtosis to be saved (default: 'mk.nii.gz')
+            Name of the mean kurtosis to be saved.
         out_ak : string, optional
-            Name of the axial kurtosis to be saved (default: 'ak.nii.gz')
+            Name of the axial kurtosis to be saved.
         out_rk : string, optional
-            Name of the radial kurtosis to be saved (default: 'rk.nii.gz')
+            Name of the radial kurtosis to be saved.
 
         References
         ----------
@@ -813,7 +795,7 @@ class ReconstDkiFlow(Workflow):
             data, affine = load_nifti(dwi)
 
             if mask is not None:
-                mask = load_nifti_data(mask).astype(np.bool)
+                mask = load_nifti_data(mask).astype(bool)
 
             dkfit, _ = self.get_fitted_tensor(data, mask, bval, bvec,
                                               b0_threshold)
@@ -932,33 +914,25 @@ class ReconstIvimFlow(Workflow):
             multiple masks at once. (default: No mask used)
         split_b_D : int, optional
             Value to split the bvals to estimate D for the two-stage process of
-            fitting
-            (default 400)
+            fitting.
         split_b_S0 : int, optional
             Value to split the bvals to estimate S0 for the two-stage process
             of fitting.
-            (default 200)
         b0_threshold : int, optional
             Threshold value for the b0 bval.
-            (default 0)
         save_metrics : variable string, optional
             List of metrics to save.
             Possible values: S0_predicted, perfusion_fraction, D_star, D
-            (default [] (all))
         out_dir : string, optional
-            Output directory (default input file directory)
+            Output directory. (default current directory)
         out_S0_predicted : string, optional
-            Name of the S0 signal estimated to be saved
-            (default: 'S0_predicted.nii.gz')
+            Name of the S0 signal estimated to be saved.
         out_perfusion_fraction : string, optional
-            Name of the estimated volume fractions to be saved
-            (default 'perfusion_fraction.nii.gz')
+            Name of the estimated volume fractions to be saved.
         out_D_star : string, optional
-            Name of the estimated pseudo-diffusion parameter to be saved
-            (default 'D_star.nii.gz')
+            Name of the estimated pseudo-diffusion parameter to be saved.
         out_D : string, optional
-            Name of the estimated diffusion parameter to be saved
-            (default 'D.nii.gz')
+            Name of the estimated diffusion parameter to be saved.
 
         References
         ----------
@@ -983,7 +957,7 @@ class ReconstIvimFlow(Workflow):
             data, affine = load_nifti(dwi)
 
             if mask is not None:
-                mask = load_nifti_data(mask).astype(np.bool)
+                mask = load_nifti_data(mask).astype(bool)
 
             ivimfit, _ = self.get_fitted_ivim(data, mask, bval, bvec,
                                               b0_threshold)
