@@ -29,13 +29,12 @@ POSSIBILITY OF SUCH DAMAGE.
 """
 
 # -*- encoding:utf-8 -*-
-from __future__ import division, absolute_import, print_function
 
 import sys
 import textwrap
 
 from dipy.workflows.docstring_parser import NumpyDocString
-from nose.tools import *
+import numpy.testing as npt
 
 if sys.version_info[0] >= 3:
     def sixu(s): return s
@@ -43,7 +42,7 @@ else:
     def sixu(s): return unicode(s, 'unicode_escape')
 
 
-doc_txt = '''\
+doc_txt = """\
   numpy.multivariate_normal(mean, cov, shape=None, spam=None)
 
   Draw values from a multivariate normal distribution with specified
@@ -106,7 +105,7 @@ doc_txt = '''\
   approximations include:
 
     - Spherical covariance (`cov` is a multiple of the identity matrix)
-    - Diagonal covariance (`cov` has non-negative elements only on the diagonal)
+    - Diagonal covariance(`cov` has non-negative elements only on the diagonal)
 
   This geometrical property can be seen in two dimensions by plotting
   generated data-points:
@@ -149,7 +148,7 @@ doc_txt = '''\
   .. index:: random
      :refguide: random;distributions, random;gauss
 
-  '''
+  """
 doc = NumpyDocString(doc_txt)
 
 doc_yields_txt = """
@@ -168,73 +167,74 @@ doc_yields = NumpyDocString(doc_yields_txt)
 
 
 def test_signature():
-    assert doc['Signature'].startswith('numpy.multivariate_normal(')
-    assert doc['Signature'].endswith('spam=None)')
+    npt.assert_(doc['Signature'].startswith('numpy.multivariate_normal('))
+    npt.assert_(doc['Signature'].endswith('spam=None)'))
 
 
 def test_summary():
-    assert doc['Summary'][0].startswith('Draw values')
-    assert doc['Summary'][-1].endswith('covariance.')
+    npt.assert_(doc['Summary'][0].startswith('Draw values'))
+    npt.assert_(doc['Summary'][-1].endswith('covariance.'))
 
 
 def test_extended_summary():
-    assert doc['Extended Summary'][0].startswith('The multivariate normal')
+    npt.assert_(doc['Extended Summary'][0].
+                startswith('The multivariate normal'))
 
 
 def test_parameters():
-    assert_equal(len(doc['Parameters']), 3)
-    assert_equal(
+    npt.assert_equal(len(doc['Parameters']), 3)
+    npt.assert_equal(
         [n for n, _, _ in doc['Parameters']], ['mean', 'cov', 'shape'])
 
     arg, arg_type, desc = doc['Parameters'][1]
-    assert_equal(arg_type, '(N, N) ndarray')
-    assert desc[0].startswith('Covariance matrix')
-    assert doc['Parameters'][0][-1][-2] == '   (1+2+3)/3'
+    npt.assert_equal(arg_type, '(N, N) ndarray')
+    npt.assert_(desc[0].startswith('Covariance matrix'))
+    npt.assert_equal(doc['Parameters'][0][-1][-2], '   (1+2+3)/3')
 
 
 def test_other_parameters():
-    assert_equal(len(doc['Other Parameters']), 1)
-    assert_equal([n for n, _, _ in doc['Other Parameters']], ['spam'])
+    npt.assert_equal(len(doc['Other Parameters']), 1)
+    npt.assert_equal([n for n, _, _ in doc['Other Parameters']], ['spam'])
     arg, arg_type, desc = doc['Other Parameters'][0]
-    assert_equal(arg_type, 'parrot')
-    assert desc[0].startswith('A parrot off its mortal coil')
+    npt.assert_equal(arg_type, 'parrot')
+    npt.assert_(desc[0].startswith('A parrot off its mortal coil'))
 
 
 def test_returns():
-    assert_equal(len(doc['Returns']), 2)
+    npt.assert_equal(len(doc['Returns']), 2)
     arg, arg_type, desc = doc['Returns'][0]
-    assert_equal(arg, 'out')
-    assert_equal(arg_type, 'ndarray')
-    assert desc[0].startswith('The drawn samples')
-    assert desc[-1].endswith('distribution.')
+    npt.assert_equal(arg, 'out')
+    npt.assert_equal(arg_type, 'ndarray')
+    npt.assert_(desc[0].startswith('The drawn samples'))
+    npt.assert_(desc[-1].endswith('distribution.'))
 
     arg, arg_type, desc = doc['Returns'][1]
-    assert_equal(arg, 'list of str')
-    assert_equal(arg_type, '')
-    assert desc[0].startswith('This is not a real')
-    assert desc[-1].endswith('anonymous return values.')
+    npt.assert_equal(arg, 'list of str')
+    npt.assert_equal(arg_type, '')
+    npt.assert_(desc[0].startswith('This is not a real'))
+    npt.assert_(desc[-1].endswith('anonymous return values.'))
 
 
 def test_notes():
-    assert doc['Notes'][0].startswith('Instead')
-    assert doc['Notes'][-1].endswith('definite.')
-    assert_equal(len(doc['Notes']), 17)
+    npt.assert_(doc['Notes'][0].startswith('Instead'))
+    npt.assert_(doc['Notes'][-1].endswith('definite.'))
+    npt.assert_equal(len(doc['Notes']), 17)
 
 
 def test_references():
-    assert doc['References'][0].startswith('..')
-    assert doc['References'][-1].endswith('2001.')
+    npt.assert_(doc['References'][0].startswith('..'))
+    npt.assert_(doc['References'][-1].endswith('2001.'))
 
 
 def test_examples():
-    assert doc['Examples'][0].startswith('>>>')
-    assert doc['Examples'][-1].endswith('True]')
+    npt.assert_(doc['Examples'][0].startswith('>>>'))
+    npt.assert_(doc['Examples'][-1].endswith('True]'))
 
 
 def test_index():
-    assert_equal(doc['index']['default'], 'random')
-    assert_equal(len(doc['index']), 2)
-    assert_equal(len(doc['index']['refguide']), 2)
+    npt.assert_equal(doc['index']['default'], 'random')
+    npt.assert_equal(len(doc['index']), 2)
+    npt.assert_equal(len(doc['index']['refguide']), 2)
 
 
 def non_blank_line_by_line_compare(a, b):
@@ -323,7 +323,7 @@ Instead of specifying the full covariance matrix, popular
 approximations include:
 
   - Spherical covariance (`cov` is a multiple of the identity matrix)
-  - Diagonal covariance (`cov` has non-negative elements only on the diagonal)
+  - Diagonal covariance(`cov` has non-negative elements only on the diagonal)
 
 This geometrical property can be seen in two dimensions by plotting
 generated data-points:
@@ -375,7 +375,7 @@ doc2 = NumpyDocString("""
 
 
 def test_parameters_without_extended_description():
-    assert_equal(len(doc2['Parameters']), 2)
+    npt.assert_equal(len(doc2['Parameters']), 2)
 
 doc3 = NumpyDocString("""
     my_signature(*params, **kwds)
@@ -400,17 +400,17 @@ doc5 = NumpyDocString(
 
 
 def test_raises():
-    assert_equal(len(doc5['Raises']), 1)
+    npt.assert_equal(len(doc5['Raises']), 1)
     name, _, desc = doc5['Raises'][0]
-    assert_equal(name, 'LinAlgException')
-    assert_equal(desc, ['If array is singular.'])
+    npt.assert_equal(name, 'LinAlgException')
+    npt.assert_equal(desc, ['If array is singular.'])
 
 
 def test_warns():
-    assert_equal(len(doc5['Warns']), 1)
+    npt.assert_equal(len(doc5['Warns']), 1)
     name, _, desc = doc5['Warns'][0]
-    assert_equal(name, 'SomeWarning')
-    assert_equal(desc, ['If needed'])
+    npt.assert_equal(name, 'SomeWarning')
+    npt.assert_equal(desc, ['If needed'])
 
 
 def test_see_also():
@@ -431,7 +431,7 @@ def test_see_also():
         foobar
     """)
 
-    assert len(doc6['See Also']) == 12
+    npt.assert_equal(len(doc6['See Also']), 12)
     for func, desc, role in doc6['See Also']:
         if func in ('func_a', 'func_b', 'func_c', 'func_f',
                     'func_g', 'func_h', 'func_j', 'func_k', 'baz.obj_q'):
@@ -512,5 +512,4 @@ class_doc_txt = """
 """
 
 if __name__ == "__main__":
-    import nose
-    nose.run()
+    npt.run_module_suite()
