@@ -125,12 +125,12 @@ def reconst_flow_core(flow):
             reconst_flow._force_overwrite = True
             reconst_flow.run(data_path, bval_path, bvec_path, mask_path,
                              out_dir=out_dir,
-                             parallel=True, nbr_processes=None)
+                             parallel=True, num_processes=None)
             reconst_flow = flow()
             reconst_flow._force_overwrite = True
             reconst_flow.run(data_path, bval_path, bvec_path, mask_path,
                              out_dir=out_dir,
-                             parallel=True, nbr_processes=2)
+                             parallel=True, num_processes=2)
 
 
 if __name__ == '__main__':
