@@ -6,9 +6,11 @@ Fiber to bundle coherence measures
 
 This demo presents the fiber to bundle coherence (FBC) quantitative
 measure of the alignment of each fiber with the surrounding fiber bundles
-[Meesters2016_HBM]_. These measures are useful in “cleaning” the results of
+[Meesters2016]_. These measures are useful in 'cleaning' the results of
 tractography algorithms, since low FBCs indicate which fibers are isolated and
-poorly aligned with their neighbors, see Fig. 1.
+poorly aligned with their neighbors, as shown in the figure below.
+
+.. _fiber_to_bundle_coherence:
 
 .. figure:: _static/fbc_illustration.png
    :scale: 60 %
@@ -21,7 +23,7 @@ poorly aligned with their neighbors, see Fig. 1.
    evaluating the kernel density estimator along the fibers. One spurious
    fiber is present which is isolated and badly aligned with the other fibers,
    and can be identified by a low LFBC value in the region where it deviates
-   from the bundle. Figure adapted from [Portegies2015_PLoSOne]_.
+   from the bundle. Figure adapted from [Portegies2015]_.
 
 Here we implement FBC measures based on kernel density estimation in the
 non-flat 5D position-orientation domain. First we compute the kernel density
@@ -30,30 +32,40 @@ and orientations) of the tractography. Then, the Local FBC (LFBC) is the
 result of evaluating the estimator along each element of the lifted fiber.
 A whole fiber measure, the relative FBC (RFBC), is calculated
 by the minimum of the moving average LFBC along the fiber.
-Details of the computation of FBC can be found in [Portegies2015_PLoSOne]_.
+Details of the computation of FBC can be found in [Portegies2015]_.
 
 """
 
 """
 The FBC measures are evaluated on the Stanford HARDI dataset
-(150 orientations, b=2000s/mm^2) which is one of the standard example datasets
-in DIPY.
+(150 orientations, b=2000 $s/mm^2$) which is one of the standard example
+datasets in DIPY_.
 """
+
+# Enables/disables interactive visualization
+interactive = False
+
 import numpy as np
-from dipy.data import (read_stanford_labels, fetch_stanford_t1,
-                       read_stanford_t1)
+from dipy.core.gradients import gradient_table
+from dipy.data import get_fnames
+from dipy.io.image import load_nifti_data, load_nifti
+from dipy.io.gradients import read_bvals_bvecs
 
 # Fix seed
 np.random.seed(1)
 
 # Read data
-hardi_img, gtab, labels_img = read_stanford_labels()
-data = hardi_img.get_data()
-labels = labels_img.get_data()
-affine = hardi_img.affine
-fetch_stanford_t1()
-t1 = read_stanford_t1()
-t1_data = t1.get_data()
+hardi_fname, hardi_bval_fname, hardi_bvec_fname = get_fnames('stanford_hardi')
+label_fname = get_fnames('stanford_labels')
+t1_fname = get_fnames('stanford_t1')
+
+data, affine = load_nifti(hardi_fname)
+labels = load_nifti_data(label_fname)
+t1_data = load_nifti_data(t1_fname)
+bvals, bvecs = read_bvals_bvecs(hardi_bval_fname, hardi_bvec_fname)
+gtab = gradient_table(bvals, bvecs)
+
+
 
 # Select a relevant part of the data (left hemisphere)
 # Coordinates given in x bounds, y bounds, z bounds
@@ -65,8 +77,8 @@ selectionmask[xa:xb, ya:yb, za:zb] = True
 
 """
 The data is first fitted to Constant Solid Angle (CDA) ODF Model. CSA is a
-good choice to estimate general fractional anisotropy (GFA), which the tissue
-classifier can use to restrict fiber tracking to those areas where the ODF
+good choice to estimate general fractional anisotropy (GFA), which the stopping
+criterion can use to restrict fiber tracking to those areas where the ODF
 shows significant restricted diffusion, thus creating a region-of-interest in
 which the computations are done.
 """
@@ -82,10 +94,10 @@ csa_peaks = peaks_from_model(csa_model, data, default_sphere,
                              min_separation_angle=45,
                              mask=selectionmask)
 
-# Tissue classifier
-from dipy.tracking.local import ThresholdTissueClassifier
+# Stopping Criterion
+from dipy.tracking.stopping_criterion import ThresholdStoppingCriterion
 
-classifier = ThresholdTissueClassifier(csa_peaks.gfa, 0.25)
+stopping_criterion = ThresholdStoppingCriterion(csa_peaks.gfa, 0.25)
 
 """
 In order to perform probabilistic fiber tracking we first fit the data to the
@@ -96,10 +108,10 @@ as the Fiber Orientation Distribution (FOD), used in the fiber tracking.
 """
 
 # Perform CSD on the original data
-from dipy.reconst.csdeconv import auto_response
+from dipy.reconst.csdeconv import auto_response_ssst
 from dipy.reconst.csdeconv import ConstrainedSphericalDeconvModel
 
-response, ratio = auto_response(gtab, data, roi_radius=10, fa_thr=0.7)
+response, ratio = auto_response_ssst(gtab, data, roi_radii=10, fa_thr=0.7)
 csd_model = ConstrainedSphericalDeconvModel(gtab, response)
 csd_fit = csd_model.fit(data_small)
 csd_fit_shm = np.lib.pad(csd_fit.shm_coeff, ((xa, dshape[0]-xb),
@@ -127,20 +139,22 @@ from dipy.tracking import utils
 mask = np.zeros(data.shape[:-1], 'bool')
 rad = 3
 mask[26-rad:26+rad, 29-rad:29+rad, 31-rad:31+rad] = True
-seeds = utils.seeds_from_mask(mask, density=[4, 4, 4], affine=affine)
+seeds = utils.seeds_from_mask(mask, affine, density=[4, 4, 4])
 
 """
 Local Tracking is used for probabilistic tractography which takes the
-direction getter along with the classifier and seeds as input.
+direction getter along with the stopping criterion and seeds as input.
 """
 
 # Perform tracking using Local Tracking
-from dipy.tracking.local import LocalTracking
+from dipy.tracking.local_tracking import LocalTracking
 
-streamlines = LocalTracking(prob_dg, classifier, seeds, affine, step_size=.5)
+streamlines_generator = LocalTracking(prob_dg, stopping_criterion, seeds,
+                                      affine, step_size=.5)
 
-# Compute streamlines and store as a list.
-streamlines = list(streamlines)
+# Compute streamlines.
+from dipy.tracking.streamline import Streamlines
+streamlines = Streamlines(streamlines_generator)
 
 """
 In order to select only the fibers that enter into the LGN, another ROI is
@@ -154,19 +168,19 @@ rad = 5
 mask_lgn[35-rad:35+rad, 42-rad:42+rad, 28-rad:28+rad] = True
 
 # Select all the fibers that enter the LGN and discard all others
-filtered_fibers2 = utils.near_roi(streamlines, mask_lgn, tol=1.8,
-                                  affine=affine)
+filtered_fibers2 = utils.near_roi(streamlines, affine, mask_lgn, tol=1.8)
+
 sfil = []
 for i in range(len(streamlines)):
     if filtered_fibers2[i]:
         sfil.append(streamlines[i])
-streamlines = list(sfil)
+streamlines = Streamlines(sfil)
 
 """
-Inspired by [Paulo_Eurographics]_, a lookup-table is created, containing
-rotated versions of the fiber propagation kernel :math:`P_t`
-[DuitsAndFranken_IJCV]_ rotated over a discrete set of orientations. See the
-`Contextual enhancement example <http://nipy.org/dipy/examples_built/contextual_enhancement.html>`_
+Inspired by [Rodrigues2010]_, a lookup-table is created, containing rotated
+versions of the fiber propagation kernel :math:`P_t` [DuitsAndFranken2011]_
+rotated over a discrete set of orientations. See the
+`Contextual enhancement example <https://dipy.org/documentation/latest/examples_built/contextual_enhancement/#example-contextual-enhancement>`_
 for more details regarding the kernel. In order to ensure rotationally
 invariant processing, the discrete orientations are required to be equally
 distributed over a sphere. By default, a sphere with 100 directions is used
@@ -209,77 +223,90 @@ fbc_sl_thres, clrs_thres, rfbc_thres = \
 
 """
 The results of FBC measures are visualized, showing the original fibers
-colored by LFBC, and the fibers after the cleaning procedure via RFBC
-thresholding.
+colored by LFBC (see :ref:`optic_radiation_before_cleaning`), and the fibers
+after the cleaning procedure via RFBC thresholding (see
+:ref:`optic_radiation_after_cleaning`).
 """
 
 # Visualize the results
-from dipy.viz import fvtk, actor
+from dipy.viz import window, actor
 
-# Create renderer
-ren = fvtk.ren()
+# Create scene
+scene = window.Scene()
 
 # Original lines colored by LFBC
 lineactor = actor.line(fbc_sl_orig, clrs_orig, linewidth=0.2)
-fvtk.add(ren, lineactor)
+scene.add(lineactor)
 
 # Horizontal (axial) slice of T1 data
-vol_actor1 = fvtk.slicer(t1_data, affine=affine)
-vol_actor1.display(None, None, 20)
-fvtk.add(ren, vol_actor1)
+vol_actor1 = actor.slicer(t1_data, affine=affine)
+vol_actor1.display(z=20)
+scene.add(vol_actor1)
 
 # Vertical (sagittal) slice of T1 data
-vol_actor2 = fvtk.slicer(t1_data, affine=affine)
-vol_actor2.display(35, None, None)
-fvtk.add(ren, vol_actor2)
+vol_actor2 = actor.slicer(t1_data, affine=affine)
+vol_actor2.display(x=35)
+scene.add(vol_actor2)
 
 # Show original fibers
-fvtk.camera(ren, pos=(-264, 285, 155), focal=(0, -14, 9), viewup=(0, 0, 1),
-            verbose=False)
-fvtk.record(ren, n_frames=1, out_path='OR_before.png', size=(900, 900))
+scene.set_camera(position=(-264, 285, 155),
+                 focal_point=(0, -14, 9),
+                 view_up=(0, 0, 1))
+window.record(scene, n_frames=1, out_path='OR_before.png', size=(900, 900))
+if interactive:
+    window.show(scene)
 
 # Show thresholded fibers
-fvtk.rm(ren, lineactor)
-fvtk.add(ren, actor.line(fbc_sl_thres, clrs_thres, linewidth=0.2))
-fvtk.record(ren, n_frames=1, out_path='OR_after.png', size=(900, 900))
+scene.rm(lineactor)
+scene.add(actor.line(fbc_sl_thres, clrs_thres, linewidth=0.2))
+window.record(scene, n_frames=1, out_path='OR_after.png', size=(900, 900))
+if interactive:
+    window.show(scene)
 
 """
+.. _optic_radiation_before_cleaning:
+
 .. figure:: OR_before.png
    :align: center
 
    The optic radiation obtained through probabilistic tractography colored by
    local fiber to bundle coherence.
 
+.. _optic_radiation_after_cleaning:
+
 .. figure:: OR_after.png
    :align: center
 
    The tractography result is cleaned (shown in bottom) by removing fibers
-   with a relative FBC (RFBC) lower than the threshold tau=0.2.
+   with a relative FBC (RFBC) lower than the threshold :math:`\tau = 0.2`.
 
 Acknowledgments
-~~~~~~~~~~~~~~~
+---------------
 The techniques are developed in close collaboration with Pauly Ossenblok of
 the Academic Center of Epileptology Kempenhaeghe & Maastricht UMC+.
 
 References
-~~~~~~~~~~
+----------
+
+.. [Meesters2016] S. Meesters, G. Sanguinetti, E. Garyfallidis, J. Portegies,
+   P. Ossenblok, R. Duits. (2016) Cleaning output of tractography via fiber to
+   bundle coherence, a new open source implementation. Human Brain Mapping
+   Conference 2016.
+
+.. [Portegies2015] J. Portegies, R. Fick, G. Sanguinetti, S. Meesters,
+   G.Girard, and R. Duits. (2015) Improving Fiber Alignment in HARDI by
+   Combining Contextual PDE flow with Constrained Spherical Deconvolution. PLoS
+   One.
+
+.. [DuitsAndFranken2011] R. Duits and E. Franken (2011) Left-invariant
+   diffusions on the space of positions and orientations and their application
+   to crossing-preserving smoothing of HARDI images. International Journal of
+   Computer Vision, 92:231-264.
+
+.. [Rodrigues2010] P. Rodrigues, R. Duits, B. Romeny, A. Vilanova (2010).
+   Accelerated Diffusion Operators for Enhancing DW-MRI. Eurographics Workshop
+   on Visual Computing for Biology and Medicine. The Eurographics Association.
+
+.. include:: ../links_names.inc
 
-.. [Meesters2016_HBM] S. Meesters, G. Sanguinetti, E. Garyfallidis,
-                      J. Portegies, P. Ossenblok, R. Duits. (2016) Cleaning
-                      output of tractography via fiber to bundle coherence, a
-                      new open source implementation. Human Brain Mapping
-                      conference 2016.
-.. [Portegies2015_PLoSOne] J. Portegies, R. Fick, G. Sanguinetti, S. Meesters,
-                           G.Girard, and R. Duits. (2015) Improving Fiber
-                           Alignment in HARDI by Combining Contextual PDE flow
-                           with Constrained Spherical Deconvolution. PLoS One.
-.. [DuitsAndFranken_IJCV] R. Duits and E. Franken (2011) Left-invariant
-                        diffusions on the space of positions and orientations
-                        and their application to crossing-preserving smoothing
-                        of HARDI images. International Journal of Computer
-                        Vision, 92:231-264.
-.. [Paulo_Eurographics] P. Rodrigues, R. Duits, B. Romeny, A. Vilanova (2010).
-                        Accelerated Diffusion Operators for Enhancing DW-MRI.
-                        Eurographics Workshop on Visual Computing for Biology
-                        and Medicine. The Eurographics Association.
 """
