@@ -20,47 +20,35 @@ The function we need to use is called resample.
 """
 
 from dipy.align.reslice import reslice
-from dipy.data import get_data
+from dipy.data import get_fnames
+from dipy.io.image import load_nifti, save_nifti
 
 """
 We use here a very small dataset to show the basic principles but you can
 replace the following line with the path of your image.
 """
 
-fimg = get_data('aniso_vox')
+fimg = get_fnames('aniso_vox')
 
 """
-We load the image and print the shape of the volume
+We load the image, the affine of the image and the voxel size. The affine is
+the transformation matrix which maps image coordinates to world (mm)
+coordinates. Then, we print the shape of the volume
 """
 
-img = nib.load(fimg)
-data = img.get_data()
-data.shape
+data, affine, voxel_size = load_nifti(fimg, return_voxsize=True)
+print(data.shape)
+print(voxel_size)
 
 """
 ``(58, 58, 24)``
-
-Load the affine of the image. The affine is the transformation matrix
-which maps image coordinates to world (mm) coordinates.
-"""
-
-affine = img.get_affine()
-
-"""
-Load and show the zooms which hold the voxel size.
-"""
-
-zooms = img.get_header().get_zooms()[:3]
-zooms
-
-"""
 ``(4.0, 4.0, 5.0)``
 
 Set the required new voxel size.
 """
 
-new_zooms = (3., 3., 3.)
-new_zooms
+new_voxel_size = (3., 3., 3.)
+print(new_voxel_size)
 
 """
 ``(3.0, 3.0, 3.0)``
@@ -68,8 +56,8 @@ new_zooms
 Start resampling (reslicing). Trilinear interpolation is used by default.
 """
 
-data2, affine2 = reslice(data, affine, zooms, new_zooms)
-data2.shape
+data2, affine2 = reslice(data, affine, voxel_size, new_voxel_size)
+print(data2.shape)
 
 """
 ``(77, 77, 40)``
@@ -77,15 +65,14 @@ data2.shape
 Save the result as a new Nifti file.
 """
 
-img2 = nib.Nifti1Image(data2, affine2)
-nib.save(img2, 'iso_vox.nii.gz')
+save_nifti('iso_vox.nii.gz', data2, affine2)
 
 """
 Or as analyze format or any other supported format.
 """
 
 img3 = nib.Spm2AnalyzeImage(data2, affine2)
-nib.save(img3,'iso_vox.img')
+nib.save(img3, 'iso_vox.img')
 
 """
 Done. Check your datasets. As you may have already realized the same
