@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 """Script to auto-generate our API docs.
 """
-from __future__ import print_function, division
 
 # stdlib imports
 import sys
@@ -62,14 +61,11 @@ if __name__ == '__main__':
 
     docwriter = ApiDocWriter(package, rst_extension='.rst',
                              other_defines=other_defines)
-    docwriter.package_skip_patterns += [r'\.fixes$',
-                                        r'\.externals$',
-                                        r'\.tracking\.interfaces.*$',
+    docwriter.package_skip_patterns += [r'\.tracking\.interfaces.*$',
                                         r'\.tracking\.gui_tools.*$',
                                         r'.*test.*$',
                                         r'^\.utils.*',
                                         r'\.boots\.resampling.*$',
-                                        r'\.fixes.*$',
                                         r'\.info.*$',
                                         r'\.pkg_info.*$',
                                         ]
